package com.ekexiu.portal.dao;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;

import org.jfw.apt.annotation.DefaultValue;
import org.jfw.apt.orm.annotation.dao.Column;
import org.jfw.apt.orm.annotation.dao.DAO;
import org.jfw.apt.orm.annotation.dao.method.From;
import org.jfw.apt.orm.annotation.dao.method.OrderBy;
import org.jfw.apt.orm.annotation.dao.method.SetSentence;
import org.jfw.apt.orm.annotation.dao.method.Where;
import org.jfw.apt.orm.annotation.dao.method.operator.Insert;
import org.jfw.apt.orm.annotation.dao.method.operator.QueryVal;
import org.jfw.apt.orm.annotation.dao.method.operator.SelectList;
import org.jfw.apt.orm.annotation.dao.method.operator.UpdateWith;
import org.jfw.apt.orm.core.defaultImpl.IntHandler;

import com.ekexiu.portal.po.Consult;
import com.ekexiu.portal.po.Tidings;
import com.ekexiu.portal.pojo.EditProfessor;

@DAO
public abstract class TidingsDao {
	@Insert
	public abstract int insert(Connection con, Tidings tidings) throws SQLException;
	
	@UpdateWith
	@From(Tidings.class)
	@Where("READ_STATUS = 0")
	@SetSentence("READ_STATUS = 1")
	public abstract int updateReadStatus(Connection con,String senderId,String consultId) throws SQLException;
	
	
	
	/**
	 * 查询当前咨询有几条未读消息
	 * @param con
	 * @param consultId 咨询ID
	 * @param senderId 登录者ID
	 * @return 返回该咨询中对方发送过来未查看的信息条数
	 * @throws SQLException
	 */
	
	@QueryVal
	@Column(handlerClass=IntHandler.class,value="COUNT(1)")
	@From(Tidings.class)
	@Where("READ_STATUS = 0")
	@DefaultValue("0")
	public abstract int queryNotReadTidings(Connection con, String consultId, String senderId) throws SQLException;
	
	/**
	 * 我的工作台最新回复
	 * @param con
	 * @param consultantId 咨询者ID
	 * @return 返回最新回复信息(包括咨询别人和别人咨询自己的最新回复)
	 * @throws SQLException
	 */
	public Tidings queryNewReply(Connection con, String consultantId) throws SQLException{
		int index = 1;
        String sql = "SELECT TIDINGS_ID,TIDINGS_CONTANT,SENDER_ID,TIDINGS.CONSULT_ID,"
        		+ " TIDINGS.CREATE_TIME,TIDINGS.READ_STATUS,CONSULT.CONSULT_TITLE"
        		+ " FROM TIDINGS INNER JOIN CONSULT ON TIDINGS.CONSULT_ID = CONSULT.CONSULT_ID "
        		+ " WHERE TIDINGS.CREATE_TIME IN "
        		+ " (SELECT MAX(TIDINGS.CREATE_TIME) FROM TIDINGS "
        		+ " INNER JOIN CONSULT ON TIDINGS.CONSULT_ID = CONSULT.CONSULT_ID AND (TIDINGS.READ_STATUS = 0) "
        		+ " AND (CONSULT.CONSULTANT_ID = ? OR CONSULT.PROFESSOR_ID = ?) AND (TIDINGS.SENDER_ID != ?)) ";
        PreparedStatement ps = con.prepareStatement(sql);
        try{
            ps.setString(index++,consultantId);
            ps.setString(index++,consultantId);
            ps.setString(index++,consultantId);
            ResultSet rs = ps.executeQuery();
            try{
                if(rs.next()){
                	Tidings tidings = new Tidings();
                	tidings.setTidingsId(rs.getString(1));
                	tidings.setTidingsContant(rs.getString(2));
                	tidings.setSenderId(rs.getString(3));
                	Consult consult = new Consult();
                	consult.setConsultId(rs.getString(4));
                	tidings.setCreateTime(rs.getString(5));
                	tidings.setReadStatus(rs.getInt(6));
                	consult.setConsultTitle(rs.getString(7));
                	tidings.setConsult(consult);
                	return tidings;
                }else{
                    return null;
                }
            }finally{
                try{rs.close();}catch(Exception e1){}
            }
        }finally{
            try{ps.close();}catch(Exception e2){}
        }
	}
	
	/**
	 * 咨询页面显示最后回复信息
	 * @param con
	 * @param consultId 咨询ID
	 * @param senderId 登陆者ID
	 * @return 返回对方最后回复的信息
	 * @throws SQLException
	 */
//	@SelectOne
//	@Nullable
//	public abstract Tidings queryLastRevovery(Connection con,String consultId,String senderId) throws SQLException;
//	
	public Tidings queryLastRevovery(Connection con,String consultId,String senderId) throws SQLException{
        int index = 1;
        String sql = "SELECT TIDINGS_ID,TIDINGS_CONTANT,SENDER_ID,CONSULT_ID,CREATE_TIME FROM TIDINGS "
        		+ " WHERE CREATE_TIME IN (SELECT MAX(CREATE_TIME) FROM TIDINGS WHERE CONSULT_ID = ?) ";
        PreparedStatement ps = con.prepareStatement(sql);
        try{
            ps.setString(index++,consultId);
            ResultSet rs = ps.executeQuery();
            try{
                if(rs.next()){
                    Tidings tidings = new Tidings();
                    tidings.setTidingsId(rs.getString(1));
                    tidings.setTidingsContant(rs.getString(2));
                    tidings.setSenderId(rs.getString(3));
                    tidings.setConsultId(rs.getString(4));
                    tidings.setCreateTime(rs.getString(5));
                    return tidings;
                }else{
                    return null;
                }
            }finally{
                try{rs.close();}catch(Exception e1){}
            }
        }finally{
            try{ps.close();}catch(Exception e2){}
        }
    }
	
	public Tidings query(Connection con,String tidingsId) throws SQLException{
        int index = 1;
        String sql = "SELECT TIDINGS_ID,TIDINGS_CONTANT,SENDER_ID,CONSULT_ID,TIDINGS.CREATE_TIME,PROFESSOR.NAME "
        		+ " FROM TIDINGS LEFT JOIN PROFESSOR ON SENDER_ID = PROFESSOR.ID WHERE TIDINGS_ID = ?";
        PreparedStatement ps = con.prepareStatement(sql);
        try{
            ps.setString(index++,tidingsId);
            ResultSet rs = ps.executeQuery();
            try{
                if(rs.next()){
                    Tidings tidings = new Tidings();
                    tidings.setTidingsId(rs.getString(1));
                    tidings.setTidingsContant(rs.getString(2));
                    EditProfessor professor = new EditProfessor();
                    professor.setId(rs.getString(3));
                    tidings.setConsultId(rs.getString(4));
                    tidings.setCreateTime(rs.getString(5));
                    professor.setName(rs.getString(6));
                    tidings.setProfessor(professor);
                    return tidings;
                }else{
                    return null;
                }
            }finally{
                try{rs.close();}catch(Exception e1){}
            }
        }finally{
            try{ps.close();}catch(Exception e2){}
        }
    }
	
	@SelectList
	@OrderBy("ORDER BY CREATE_TIME")
	public abstract List<Tidings> queryList(Connection con,String consultId) throws SQLException;
	
	public List<Tidings> queryCon(Connection con,String consultId) throws SQLException{
        int index = 1;
        String sql = "SELECT TIDINGS_ID,TIDINGS_CONTANT,SENDER_ID,TIDINGS.CONSULT_ID,TIDINGS.CREATE_TIME,PROFESSOR.NAME "
        		+ " FROM TIDINGS INNER JOIN PROFESSOR ON SENDER_ID = PROFESSOR.ID WHERE TIDINGS.CONSULT_ID = ? ORDER BY TIDINGS.CREATE_TIME";
        PreparedStatement ps = con.prepareStatement(sql);
        try{
            ps.setString(index++,consultId);
            ResultSet rs = ps.executeQuery();
            try{
                List<Tidings> tidingsList = new ArrayList<Tidings>();
                while(rs.next()){
                    Tidings tidings =  new Tidings();
                    tidings.setTidingsId(rs.getString(1));
                    tidings.setTidingsContant(rs.getString(2));
                    EditProfessor professor = new EditProfessor();
                    professor.setId(rs.getString(3));
                    tidings.setConsultId(rs.getString(4));
                    tidings.setCreateTime(rs.getString(5));
                    professor.setName(rs.getString(6));
                    tidings.setProfessor(professor);
                    tidingsList.add(tidings);
                }
                return tidingsList;
            }finally{
                try{rs.close();}catch(Exception e1){}
            }
        }finally{
            try{ps.close();}catch(Exception e2){}
        }
    }
	
}
