package com.ekexiu.portal.editor;

import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.Writer;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.jfw.apt.annotation.Autowrie;
import org.jfw.apt.annotation.Bean;
import org.jfw.util.ConstData;
import org.jfw.util.json.JsonService;
import org.jfw.util.web.fileupload.Item;
import org.jfw.util.web.fileupload.UploadItemIterator;
import org.jfw.util.web.fileupload.impl.UploadItemIteratorImpl;

import com.ekexiu.portal.editor.define.BaseState;
import com.ekexiu.portal.editor.define.State;

@Bean
public class Controller {

    @Autowrie
    private EditorConfig config;

    public EditorConfig getConfig() {
        return config;
    }

    public void setConfig(EditorConfig config) {
        this.config = config;
    }

    public void service(HttpServletRequest req, HttpServletResponse res, int _viewType) throws javax.servlet.ServletException, java.io.IOException {
        req.setCharacterEncoding("utf-8");
        res.setHeader("Content-Type", "text/html");
        String callbackName = req.getParameter("callback");
        String ret = null;
        if (callbackName != null) {
            if (!validCallbackName(callbackName)) {
                ret = new BaseState(false, 401).toJSONString();
            } else {
                ret = callbackName + "(" + invoke(req) + ");";
            }
        } else {
            ret = invoke(req);
        }
        Writer out = res.getWriter();
        try {
            out.write(ret);
        } finally {
            out.close();
        }
    }

    public String invoke(HttpServletRequest req) {
        String actionType = req.getParameter("action");
        if ((actionType == null) || (!mapping.containsKey(actionType))) {
            return new BaseState(false, 101).toJSONString();
        }

        State state = new BaseState(false, 101);

        int actionCode = getType(actionType);

        switch (actionCode) {
        case 0:

            return JsonService.toJson(this.config.getAllConfig());
        case 1:
        case 2:
        case 3:
        case 4:
            state = this.upload(req, actionCode);
            break;

        }
        return state.toJSONString();
    }

    public boolean validCallbackName(String name) {
        if (name.matches("^[a-zA-Z_]+[\\w0-9_]*$")) {
            return true;
        }
        return false;
    }

    private State upload(HttpServletRequest req, int actionCode) {
        if (2 == actionCode) {
            return this.uploadBase64(req);
        }
        boolean isAjaxUpload = req.getHeader("X_Requested_With") != null;
        if (!UploadItemIteratorImpl.isMultipartContent(req)) {
            return new BaseState(false, 5);
        }
        try {
            if (isAjaxUpload) {
                req.setCharacterEncoding("UTF-8");
            }
            String savePath = this.config.getImagePathFormat();
            long maxSize = this.config.getImageMaxSize();
            String afs = this.config.getImageAllowFiles();
            if (actionCode == 3) {
                savePath = this.config.getVideoPathFormat();
                maxSize = this.config.getVideoMaxSize();
                afs = this.config.getVideoAllowFiles();
            }
            if (actionCode == 4) {
                savePath = this.config.getFilePathFormat();
                maxSize = this.config.getFileMaxSize();
                afs = this.config.getFileAllowFiles();
            }
            List<String> afList = this.config.addDot(this.config.from(afs));

            UploadItemIterator it = UploadItemIteratorImpl.build(req);
            try {
                while (it.hasNext()) {
                    Item item = it.next();
                    if (!item.isFormField()) {
                        String filename = item.getName();
                        String suffix = filename.substring(filename.lastIndexOf(".")).toLowerCase();
                        if (!afList.contains(suffix)) {
                            return new BaseState(false, 8);
                        }
                        filename = filename.substring(0, filename.length() - suffix.length());
                        savePath = savePath + suffix;
                        savePath = PathFormat.parse(savePath, filename);
                        State storageState = this.saveFileByInputStream(item.getInputStream(), savePath, maxSize);
                        if (storageState.isSuccess()) {
                            storageState.putInfo("url", PathFormat.format(savePath));
                            storageState.putInfo("type", suffix);
                            storageState.putInfo("original", filename + suffix);
                        }
                        return storageState;
                    }
                }
                return new BaseState(false, 7);
            } finally {
                it.clean();
            }
        } catch (IOException e) {
        }

        return new BaseState(false, 4);
    }

    private static boolean validSize(byte[] data, long length) {
        return data.length <= length;
    }

    private State uploadBase64(HttpServletRequest req) {
        String fn = this.config.getScrawlFieldName();
        String content = req.getParameter(fn);
        byte[] data = org.jfw.apt.util.Base64.decodeBase64(content.getBytes(ConstData.UTF8));

        long maxSize = this.config.getScrawlMaxSize();
        if (!validSize(data, maxSize)) {
            return new BaseState(false, 1);
        }
        String suffix = ".jpg";

        String savePath = PathFormat.parse(this.config.getScrawlPathFormat(), "scrawl");

        savePath = savePath + suffix;
        State storageState = saveBinaryFile(data, savePath);
        if (storageState.isSuccess()) {
            storageState.putInfo("url", PathFormat.format(savePath));
            storageState.putInfo("type", suffix);
            storageState.putInfo("original", "");
        }
        return storageState;

    }

    public static int getType(String key) {
        return ((Integer) mapping.get(key)).intValue();
    }

    public static final int BUFFER_SIZE = 8192;

    public State saveBinaryFile(byte[] data, String path) {
        File file = new File(this.config.getRootPath(), path);

        State state = valid(file);
        if (!state.isSuccess()) {
            return state;
        }
        try {
            BufferedOutputStream bos = new BufferedOutputStream(new FileOutputStream(file));
            bos.write(data);
            bos.flush();
            bos.close();
        } catch (IOException ioe) {
            return new BaseState(false, 4);
        }
        state = new BaseState(true, file.getAbsolutePath());
        state.putInfo("size", data.length);
        state.putInfo("title", file.getName());
        return state;
    }

    public State saveFileByInputStream(InputStream is, String path, long maxSize) {
        State state = null;
        File file = new File(this.config.getRootPath(), path);
        if (file.exists()) {
            return new BaseState(false, 2);
        }
        File parent = file.getParentFile();
        if(!parent.exists()){
            if(!parent.mkdirs())return new BaseState(false, 3);
        }

        byte[] dataBuf = new byte[4096];
        BufferedInputStream bis = new BufferedInputStream(is, 8192);
        try {
            try {
                BufferedOutputStream bos = new BufferedOutputStream(new FileOutputStream(file), 8192);

                int count = 0;
                while ((count = bis.read(dataBuf)) != -1) {
                    bos.write(dataBuf, 0, count);
                }
                bos.flush();
                bos.close();
                if (file.length() > maxSize) {
                    file.delete();
                    return new BaseState(false, 1);
                }
                state = new BaseState(true);
                state.putInfo("size", file.length());
                state.putInfo("title", file.getName());
                return state;
            } finally {
                is.close();
            }
        } catch (IOException localIOException) {
        }
        return new BaseState(false, 4);
    }

    private static State valid(File file) {
        File parentPath = file.getParentFile();
        if ((!parentPath.exists()) && (!parentPath.mkdirs())) {
            return new BaseState(false, 3);
        }
        if (!parentPath.canWrite()) {
            return new BaseState(false, 2);
        }
        return new BaseState(true);
    }

    public static final Map<String, Integer> mapping = new HashMap<String, Integer>();
    public static final int CONFIG = 0;
    public static final int UPLOAD_IMAGE = 1;
    public static final int UPLOAD_SCRAWL = 2;
    public static final int UPLOAD_VIDEO = 3;
    public static final int UPLOAD_FILE = 4;
    static {
        mapping.put("config", CONFIG);
        mapping.put("uploadimage", UPLOAD_IMAGE);
        mapping.put("uploadscrawl", UPLOAD_SCRAWL);
        mapping.put("uploadvideo", UPLOAD_VIDEO);
        mapping.put("uploadfile", UPLOAD_FILE);
    }
}
