package com.ekexiu.portal.job;

import com.ekexiu.portal.cms.TemplateService;
import com.ekexiu.portal.service.WeixinService;
import com.ekexiu.portal.views.handler.LogHandler;
import com.ekexiu.portal.views.service.Main;
import com.ekexiu.push.service.PushService;
import org.jfw.apt.annotation.Bean;
import org.jfw.util.bean.AfterBeanFactory;
import org.jfw.util.bean.BeanFactory;
import org.jfw.util.context.JfwAppContext;

import javax.sql.DataSource;
import java.text.DateFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.concurrent.ScheduledExecutorService;
import java.util.concurrent.TimeUnit;

@Bean
public class TaskJob implements AfterBeanFactory {
	private ScheduledExecutorService service;
	private DataSource dataSource;

	@Override
	public void handle(BeanFactory bf) throws Throwable {
		this.dataSource =(DataSource) bf.getBean("dataSource");
		ArticleTaskJobEntry atje = (ArticleTaskJobEntry) bf.getBean("com_ekexiu_portal_job_ArticleTaskJobEntry");
		TaskJobEntry tje = (TaskJobEntry) bf.getBean("com_ekexiu_portal_job_TaskJobEntry");
		ProScoreTaskJobEntry pstje = (ProScoreTaskJobEntry) bf.getBean("com_ekexiu_portal_job_ProScoreTaskJobEntry");
		// UserLogTaskJobEntry ultje = (UserLogTaskJobEntry)
		// bf.getBean("com_ekexiu_portal_job_UserLogTaskJobEntry");
		DictTaskJobEntry dtje = (DictTaskJobEntry) bf.getBean("com_ekexiu_portal_job_DictTaskJobEntry");
		HotKeyJobEntry hkje = (HotKeyJobEntry) bf.getBean("com_ekexiu_portal_job_HotKeyJobEntry");
		final WeixinService weixin = (WeixinService) bf.getBean("com_ekexiu_portal_service_WeixinService");
		final PushService pushService = (PushService) bf.getBean("com_ekexiu_push_service_PushService");

		final TemplateService templateService = (TemplateService) bf.getBean("com_ekexiu_portal_cms_TemplateService");

		DemandInvalidJob dij = (DemandInvalidJob) bf.getBean("com_ekexiu_portal_job_DemandInvalidJob");

		long delayTime = tje.getDelayTime();
		long task = getTimeMillis(tje.getTaskTime());
		long taskTime = task - System.currentTimeMillis();
		taskTime = taskTime > 0 ? taskTime : delayTime + taskTime;

		this.service = JfwAppContext.getScheduledExecutorService();
		// 第二个参数为首次执行的延时时间，第三个参数为定时执行的间隔时间
		service.scheduleAtFixedRate(atje, 1, atje.getDelayTime(), TimeUnit.SECONDS);
		service.scheduleAtFixedRate(tje, taskTime, delayTime, TimeUnit.MILLISECONDS);

		long pstjeTask = getTimeMillis(pstje.getTaskTime());
		long pstjeTaskTime = pstjeTask - System.currentTimeMillis();
		pstjeTaskTime = pstjeTaskTime > 0 ? pstjeTaskTime : pstjeTaskTime + pstje.getDelayTime();
		service.scheduleAtFixedRate(pstje, pstjeTaskTime, pstje.getDelayTime(), TimeUnit.MILLISECONDS);
		// service.scheduleAtFixedRate(ultje, taskTime, delayTime,
		// TimeUnit.MILLISECONDS);
		service.scheduleAtFixedRate(dtje, 1, dtje.getDelayTime(), TimeUnit.SECONDS);

		long hkjeTask = getTimeMillis(hkje.getTaskTime());
		long hkjeTaskTime = hkjeTask - System.currentTimeMillis();
		hkjeTaskTime = hkjeTaskTime > 0 ? hkjeTaskTime : hkjeTaskTime + hkje.getDelayTime();
		service.scheduleAtFixedRate(hkje, hkjeTaskTime, hkje.getDelayTime(), TimeUnit.MILLISECONDS);
		if (hkjeTaskTime > 300 * 1000) {
			service.submit(hkje);
		}

		service.scheduleAtFixedRate(new Runnable() {
			@Override
			public void run() {
				weixin.refresh();
			}
		}, 0, weixin.getDelayTime(), TimeUnit.SECONDS);
		service.scheduleAtFixedRate(new Runnable() {
			@Override
			public void run() {
				pushService.refresh();
			}
		}, 0, 2, TimeUnit.SECONDS);
		service.scheduleAtFixedRate(dij, 0, 5, TimeUnit.MINUTES);
		service.scheduleWithFixedDelay(new Runnable() {
			@Override
			public void run() {
				templateService.handle(dataSource);
			}
		}, 0, templateService.getRate(), TimeUnit.MILLISECONDS);

		Main main = (Main) bf.getBean("com_ekexiu_portal_views_service_Main");
		for (LogHandler lh : main.getHandlers()) {
			service.scheduleAtFixedRate(lh, lh.getInitialDelay(), lh.getPeriod(), TimeUnit.MILLISECONDS);
			JfwAppContext.addDestoryed(lh);
		}

	}

	private static long getTimeMillis(String time) {
		try {
			DateFormat dateFormat = new SimpleDateFormat("yy-MM-dd HH:mm:ss");
			DateFormat dayFormat = new SimpleDateFormat("yy-MM-dd");
			Date curDate = dateFormat.parse(dayFormat.format(new Date()) + " " + time);
			return curDate.getTime();
		} catch (ParseException e) {
			e.printStackTrace();
		}
		return 0;
	}

}
