package com.ekexiu.portal.platform;

import org.jfw.apt.annotation.Autowrie;
import org.jfw.apt.annotation.DefaultValue;
import org.jfw.apt.annotation.Nullable;
import org.jfw.apt.web.annotation.Path;
import org.jfw.apt.web.annotation.operate.Get;
import org.jfw.apt.web.annotation.operate.Post;
import org.jfw.apt.web.annotation.param.JdbcConn;
import org.jfw.apt.web.annotation.param.PathVar;
import org.jfw.util.PageQueryResult;
import org.jfw.util.StringUtil;

import java.sql.Connection;
import java.sql.SQLException;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;

/**
 * Created by TT on 2018/5/21.
 */
@Path("/platformConsole")
public class Console {

    @Autowrie
    private PlatformDao platformDao;

    public PlatformDao getPlatformDao() {
        return platformDao;
    }

    public void setPlatformDao(PlatformDao platformDao) {
        this.platformDao = platformDao;
    }

    /*
	运营系统使用
	 */
    @Path("/createAccount")
    @Post
    public void createAccount(@JdbcConn(true) Connection con, String name, String email) throws SQLException {
        String id = StringUtil.buildUUID();
        PlatformUser platformUser = new PlatformUser();
        platformUser.setId(id);
        platformUser.setEmail(email);
        platformUser.setPasswd(StringUtil.md5("123456"));
        platformUser.setState("1");
        this.platformDao.insert(con, platformUser);
        PlatformInfo platformInfo = new PlatformInfo();
        platformInfo.setId(id);
        platformInfo.setName(name);
        this.platformDao.insert(con, platformInfo);
    }

    @Path("/updateAccount")
    @Post
    public void updateAccount(@JdbcConn(true) Connection con, String id, String name, String email) throws SQLException {
        this.platformDao.updateEmail(con, id, email);
        this.platformDao.updateName(con, id, name);
    }

    @Path("/createCheck")
    @Get
    public int createCheck(@JdbcConn Connection con, String name, String email) throws SQLException {
        PlatformUser platformUser = this.platformDao.queryUser(con, email);
        if (platformUser != null) {
            return 2;//该邮箱已被注册
        }
        PlatformInfo platformInfo = this.platformDao.queryInfoByName(con, name);
        if ((platformInfo != null) && (this.platformDao.queryUserById(con, platformInfo.getId()) != null)) {
            return 3;//该平台已注册帐号
        }
        return 1;//可以创建
    }

    @Path("/editCheck")
    @Post
    public int editCheck(@JdbcConn Connection con, String id, String name, String email) throws SQLException {
        PlatformUser platformUser = this.platformDao.queryUser(con, email);
        if ((platformUser != null)&&(!Objects.equals(platformUser.getId(), id))) {
            return 2;//该邮箱已被注册
        }
        PlatformInfo platformInfo = this.platformDao.queryInfoByName(con, name);
        if ((platformInfo != null) && (!Objects.equals(platformInfo.getId(), id))) {
            return 3;//该平台已注册帐号
        }
        return 1;
    }

    @Get
    @Path("/queryAccount/{id}")
    public Map<String, Object> queryAccount(@JdbcConn Connection con,@PathVar String id)throws SQLException {
        PlatformInfo platformInfo = this.platformDao.queryInfo(con, id);
        PlatformUser platformUser = this.platformDao.queryUserById(con, id);
        Map<String, Object> map = new HashMap<String, Object>();
        map.put("id", id);
        map.put("email", platformUser.getEmail());
        map.put("name", platformInfo.getName());
        map.put("state", platformUser.getState());
        return map;
    }

    @Get
    @Path("/pq")
    public PageQueryResult<PlatformInfo> query(@JdbcConn Connection con, @Nullable String name, @Nullable String bt, @Nullable String et, @DefaultValue("1") int pageNo, @DefaultValue("10") int pageSize) throws SQLException {
        return this.platformDao.query(con, name == null ? null : "%" + name + "%", bt == null ? null : bt + "000000", et == null ? null : et + "235959", pageSize, pageNo);
    }

    @Get
    @Path("/pqButtedProfessors")
    public PageQueryResult<ButtedProfessorInfo> pageQueryButtedProfessorinfos(@JdbcConn Connection con,@Nullable String pid,@Nullable String name, int pageSize, int pageNo)
            throws SQLException {
        PageQueryResult<ButtedProfessorInfo> ret = new PageQueryResult<ButtedProfessorInfo>();
        if (pid != null) {
            ret = this.platformDao.queryButtedProfessorInfo(con, pid, name == null ? null : ("%" + name + "%"), pageSize, pageNo);
        }
        return ret;
    }

    @Get
    @Path("/pqButtedOrg")
    public PageQueryResult<ButtedOrgInfo> pageQueryButtedOrg(@JdbcConn Connection con,@Nullable String pid,@Nullable String name, int pageSize, int pageNo)
            throws SQLException {
        PageQueryResult<ButtedOrgInfo> ret = new PageQueryResult<ButtedOrgInfo>();
        if (pid != null) {
            ret = this.platformDao.queryButtedOrgInfo(con, pid, name == null ? null : ("%" + name + "%"), pageSize, pageNo);
        }
        return ret;
    }
}
