package com.ekexiu.portal.platform;

import com.ekexiu.portal.platform.msg.PlatformMsgDao;
import com.ekexiu.portal.platform.msg.PlatformMsgIdx;
import com.ekexiu.portal.platform.msg.PlatformMsgRec;
import org.jfw.apt.annotation.Autowrie;
import org.jfw.apt.web.annotation.Path;
import org.jfw.apt.web.annotation.operate.Get;
import org.jfw.apt.web.annotation.operate.Post;
import org.jfw.apt.web.annotation.param.JdbcConn;
import org.jfw.util.DateUtil;
import org.jfw.util.exception.JfwBaseException;
import org.jfw.util.jdbc.JdbcUtil;

import java.sql.Connection;
import java.sql.SQLException;
import java.util.List;

@Path("/platform/msg")
public class PlatformMsgService {

	@Autowrie
	private PlatformMsgDao platformMsgDao;

	public PlatformMsgDao getPlatformMsgDao() {
		return platformMsgDao;
	}

	public void setPlatformMsgDao(PlatformMsgDao platformMsgDao) {
		this.platformMsgDao = platformMsgDao;
	}

	@Get
	@Path("/idx")
	public List<PlatformMsgIdx> query(@JdbcConn Connection con, String provider) throws SQLException {
		return this.platformMsgDao.query(con, provider);
	}

	@Get
	@Path("/rec")
	public List<PlatformMsgRec> query(@JdbcConn Connection con, String provider, String pid, String requestor) throws SQLException {
		return this.platformMsgDao.query(con, provider, pid, requestor);
	}

	@Post
	@Path("/readed")
	public int readed(@JdbcConn(true) Connection con, String provider, String pid, String requestor) throws SQLException {
		return this.platformMsgDao.readed(con, provider, pid, requestor);
	}

	@Post
	@Path("/delete")
	public int delete(@JdbcConn(true) Connection con, String provider, String pid, String requestor) throws SQLException {
		return this.platformMsgDao.delete(con, provider, pid, requestor);
	}

	@Post
	@Path("/send")
	public int send(@JdbcConn(true) Connection con, String provider, String pid, String requestor, String cnt) throws SQLException, JfwBaseException {
		String time = DateUtil.formatDateTime(System.currentTimeMillis());
		PlatformMsgRec mr = new PlatformMsgRec();
		mr.setCnt(cnt);
		mr.setOpTime(time);
		mr.setPid(pid);
		mr.setProvider(provider);
		mr.setRequestor(requestor);
		mr.setMsgType(1);
		try {
			this.platformMsgDao.insert(con, mr);
		} catch (SQLException ee) {
			if ("23505".equals(ee.getSQLState())) {
				throw new JfwBaseException(-60001, "interval to small");
			}
		}
		this.platformMsgDao.updateActivedIdx(con, requestor, provider, pid, time, cnt, time);
		return 1;
	}

	@Get
	@Path("/unread")
	public int unreadSum(@JdbcConn Connection con, String provider)throws SQLException {
		return this.platformMsgDao.unreadSum(con, provider);
	}

	@Post
	@Path("/frecv")
	public void frecv(@JdbcConn(true) Connection con, String provider, String pid, String requestor, String cnt, String time)
			throws SQLException, JfwBaseException {
		PlatformMsgRec mr = new PlatformMsgRec();
		mr.setCnt(cnt);
		mr.setOpTime(time);
		mr.setPid(pid);
		mr.setProvider(provider);
		mr.setRequestor(requestor);
		mr.setMsgType(0);
		this.platformMsgDao.insert(con, mr);
		PlatformMsgIdx mi = new PlatformMsgIdx();
		mi.setActived(true);
		mi.setCnt(cnt);
		mi.setOpTime(time);
		mi.setPid(pid);
		mi.setProvider(provider);
		mi.setRequestor(requestor);
		mi.setUnread(1);
		this.platformMsgDao.insert(con, mi);
	}

	@Post
	@Path("/recv")
	public void recv(@JdbcConn Connection con, String provider, String pid, String requestor, String cnt, String time) throws SQLException, JfwBaseException {
		try {
			PlatformMsgRec mr = new PlatformMsgRec();
			mr.setCnt(cnt);
			mr.setOpTime(time);
			mr.setPid(pid);
			mr.setProvider(provider);
			mr.setRequestor(requestor);
			mr.setMsgType(0);
			try {
				this.platformMsgDao.insert(con, mr);
			} catch (SQLException ee) {
				if ("23505".equals(ee.getSQLState())) {
					JdbcUtil.rollback(con);
					return;
				}
			}
			if (this.platformMsgDao.updateIdxFlag(con, provider, pid, requestor, time) == 0) {
				this.platformMsgDao.updateIdxFull(con, provider, pid, requestor, time, cnt, time);
			}
			con.commit();
		} catch (SQLException e) {
			JdbcUtil.rollback(con);
		} finally {
			JdbcUtil.close(con);
		}
	}
	
	@Get
	@Path("/sync")
	public List<PlatformMsgRec> syncData(@JdbcConn Connection con,String pid,String requestor,String provider,String opTime,int rows)throws SQLException{
		return this.platformMsgDao.queryOld(con, pid, opTime, provider, requestor, rows);
	}
}
