package com.ekexiu.portal.product;

import org.jfw.apt.annotation.DefaultValue;
import org.jfw.apt.annotation.Nullable;
import org.jfw.apt.orm.annotation.dao.Column;
import org.jfw.apt.orm.annotation.dao.DAO;
import org.jfw.apt.orm.annotation.dao.method.Exclude;
import org.jfw.apt.orm.annotation.dao.method.From;
import org.jfw.apt.orm.annotation.dao.method.LimitColumn;
import org.jfw.apt.orm.annotation.dao.method.OrderBy;
import org.jfw.apt.orm.annotation.dao.method.Select;
import org.jfw.apt.orm.annotation.dao.method.SetSentence;
import org.jfw.apt.orm.annotation.dao.method.Where;
import org.jfw.apt.orm.annotation.dao.method.operator.DeleteWith;
import org.jfw.apt.orm.annotation.dao.method.operator.Insert;
import org.jfw.apt.orm.annotation.dao.method.operator.LimitSelect;
import org.jfw.apt.orm.annotation.dao.method.operator.PageSelect;
import org.jfw.apt.orm.annotation.dao.method.operator.QueryList;
import org.jfw.apt.orm.annotation.dao.method.operator.QueryVal;
import org.jfw.apt.orm.annotation.dao.method.operator.SelectList;
import org.jfw.apt.orm.annotation.dao.method.operator.SelectOne;
import org.jfw.apt.orm.annotation.dao.method.operator.Update;
import org.jfw.apt.orm.annotation.dao.method.operator.UpdateWith;
import org.jfw.apt.orm.annotation.dao.param.GroupSqlColumn;
import org.jfw.apt.orm.annotation.dao.param.In;
import org.jfw.apt.orm.annotation.dao.param.LessThan;
import org.jfw.apt.orm.annotation.dao.param.UnEquals;
import org.jfw.apt.orm.core.defaultImpl.LongHandler;
import org.jfw.apt.orm.core.defaultImpl.StringHandler;
import org.jfw.util.PageQueryResult;

import java.sql.Connection;
import java.sql.SQLException;
import java.util.List;

/**
 * Created by TT on 2018/7/6.
 */
@DAO
public interface ProductDao {

    @Insert
    int insert(Connection con, Product product) throws SQLException;

    @Insert
    int insert(Connection con, ProductPro productPro) throws SQLException;

    @DeleteWith
    @From(ProductPro.class)
    int deleteProductPro(Connection con, String id) throws SQLException;

    @DeleteWith
    @From(ProductPro.class)
    int deletePro(Connection con, String professor) throws SQLException;

    @DeleteWith
    @From(ProductPro.class)
    int deletePro(Connection con, String id, String professor) throws SQLException;

    @Update
    int update(Connection con, Product product) throws SQLException;

    @UpdateWith
    @From(Product.class)
    @Where("STATE<>'0'")
    @SetSentence("STATE = '0'")
    int logicDelete(Connection con, String id) throws SQLException;

    @UpdateWith
    @From(Product.class)
    @SetSentence("PAGE_VIEWS=PAGE_VIEWS+1")
    int incPageViews(Connection con, String id) throws SQLException;

    @SelectList
    List<ProductPro> queryPro(Connection con, String id) throws SQLException;

    @DefaultValue("0")
    @QueryVal
    @Column(value = "COUNT(1)", handlerClass = LongHandler.class)
    @From(Product.class)
    @Where("STATE='1'")
    long countPublish(Connection con, String owner) throws SQLException;

    @SelectOne
    @Nullable
    Product queryById(Connection con, String id) throws SQLException;

    @SelectOne
    @Nullable
    Product queryByShareId(Connection con, long shareId) throws SQLException;

    @SelectList
    List<Product> queryById(Connection con, @In String[] id) throws SQLException;

    @LimitSelect
    @Where("STATE='1'")
    @OrderBy("ORDER BY MODIFY_TIME DESC")
    List<Product> queryPublish(Connection con, String owner, @LessThan String modifyTime, int rows) throws SQLException;

    @PageSelect
    @OrderBy("ORDER BY STATE DESC,MODIFY_TIME DESC")
    @Where(" STATE = '1' OR STATE='2' ")
    PageQueryResult<Product> pageQuery(Connection con, @Nullable @GroupSqlColumn(handlerClass = StringHandler.class, value = {"NAME LIKE ?", "CNT LIKE ?", "KEYWORDS LIKE ?"}, isAnd = false) String key, String owner, int pageSize, int pageNo) throws SQLException;

    @QueryList
    @From(Product.class)
    @Select(Product.class)
    @Where(" (STATE='1' OR STATE='2') ")
    @OrderBy("ORDER BY STATE DESC,MODIFY_TIME DESC")
    List<CountProduct> queryByOwner(Connection con, @Nullable @GroupSqlColumn(handlerClass = StringHandler.class, value = {"NAME LIKE ?", "CNT LIKE ?", "KEYWORDS LIKE ?"}, isAnd = false) String key, String owner) throws SQLException;

    @LimitSelect
    @Where("STATE = '1'")
    @OrderBy(cols = {@LimitColumn(value = "sortFirst", asc = false, handlerClass = LongHandler.class), @LimitColumn(value = "modifyTime", asc = false), @LimitColumn(value = "id", asc = false)}, value = "")
    List<Product> indexSearch(Connection con, @Nullable @GroupSqlColumn(handlerClass = StringHandler.class, value = {"NAME LIKE ?", "CNT LIKE ?", "KEYWORDS LIKE ?", "OWNER IN (SELECT ID FROM ORGANIZATION WHERE NAME LIKE ? FOR_SHORT LIKE ?"}, additional = 1, isAnd = false, force = true) String key, long sortFirst, String modifyTime, String id, int rows) throws SQLException;


    @LimitSelect
    @OrderBy(" ORDER BY PAGE_VIEWS DESC")
    @Where("STATE='1'")
    List<Product> queryByOwnerWithPageViews(Connection con, String owner, @Nullable @UnEquals String id, int rows)
            throws SQLException;

    @Update
    @Exclude("modifyTime")
    int conUpdate(Connection con, Product product) throws SQLException;
}
