package com.ekexiu.portal.util;

import java.io.IOException;
import java.nio.ByteBuffer;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

import javax.websocket.OnClose;
import javax.websocket.OnMessage;
import javax.websocket.OnOpen;
import javax.websocket.PongMessage;
import javax.websocket.Session;
import javax.websocket.server.ServerEndpoint;

@ServerEndpoint("/websocket/msg")
public class WebMsgSocketServlet {

	private static final Object lock = new Object();

	private static final Map<String, Session> sessions = new ConcurrentHashMap<String, Session>();
	private static final String[] TYPE_LIST = new String[]{"www","app"};
	
	public static void sendMessage(String id ,String cnt){
		for(String type:TYPE_LIST){
			String key = id+"~"+type;
			Session session = sessions.get(key);
			if(session!=null && session.isOpen()){
				try {
					session.getBasicRemote().sendText(cnt);
				} catch (IOException e) {
				}
			}
			
		}
	}
	public static boolean invalidType(String type){
		for(String s:TYPE_LIST){
			if(s.equals(type))
				return false;
		}
		return true;
	}

	@OnMessage
	public void echoTextMessage(Session session, String msg, boolean last) {
		// try {
		// if (session.isOpen()) {
		// session.getBasicRemote().sendText(msg, last);
		// }
		// } catch (IOException e) {
		// try {
		// session.close();
		// } catch (IOException e1) {
		// // Ignore
		// }
		// }
	}

	@OnMessage
	public void echoBinaryMessage(Session session, ByteBuffer bb, boolean last) {
		// try {
		// if (session.isOpen()) {
		// session.getBasicRemote().sendBinary(bb, last);
		// }
		// } catch (IOException e) {
		// try {
		// session.close();
		// } catch (IOException e1) {
		// // Ignore
		// }
		// }
	}

	@OnMessage
	public void echoPongMessage(PongMessage pm) {
		// NO-OP
	}

	@OnOpen
	public void open(Session session) {
		String qs = session.getQueryString();
		String[] ps = qs.split("&");
		String id = null;
		String type = null;
		for (String p : ps) {
			if (p != null && p.length() > 3) {
				if (p.startsWith("id=")) {
					id = p.substring(3);
				} else if (p.startsWith("pm=")) {
					type = p.substring(3);
				}
			}
		}

		if (id == null || type == null || invalidType(type) ) {
			try {
				session.close();
			} catch (IOException e) {
			}
			return;
		}
		String sessionFlag = id + "~" + type;
		Session old = null;
		synchronized (lock) {
			old = sessions.get(sessionFlag);
			sessions.put(sessionFlag, session);
		}
		if (old != null && old.isOpen()) {
			try {
				old.close();
			} catch (IOException e) {
			}
		}
	}

	@OnClose
	public void close(Session session) {
		String qs = session.getQueryString();
		String[] ps = qs.split("&");
		String id = null;
		String type = null;
		for (String p : ps) {
			if (p != null && p.length() > 3) {
				if (p.startsWith("id=")) {
					id = p.substring(3);
				} else if (p.startsWith("pm=")) {
					type = p.substring(3);
				}
			}
		}

		if (id == null || type == null) {
			return;
		}
		String sessionFlag = id + "~" + type;
		synchronized (lock) {
			if (session.equals(sessions.get(sessionFlag)))
				sessions.remove(sessionFlag);
		}
	}
}
