package com.ekexiu.portal.views.dao;


import com.ekexiu.portal.views.pojo.DayData;
import com.ekexiu.portal.views.pojo.PpatentSum;
import com.ekexiu.portal.views.pojo.ResourceSum;
import com.ekexiu.portal.views.pojo.WareSum;
import org.jfw.apt.annotation.Nullable;
import org.jfw.apt.orm.annotation.dao.DAO;
import org.jfw.apt.orm.annotation.dao.method.Exclude;
import org.jfw.apt.orm.annotation.dao.method.OrderBy;
import org.jfw.apt.orm.annotation.dao.method.operator.PageQuery;
import org.jfw.apt.orm.annotation.dao.param.Alias;
import org.jfw.apt.orm.annotation.dao.param.GroupSqlColumn;
import org.jfw.apt.orm.annotation.dao.param.GtEq;
import org.jfw.apt.orm.annotation.dao.param.Like;
import org.jfw.apt.orm.annotation.dao.param.LtEq;
import org.jfw.apt.orm.core.defaultImpl.StringHandler;
import org.jfw.util.PageQueryResult;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.LinkedList;
import java.util.List;

@DAO
public abstract class DayDao {
    public List<DayData> query(Connection con, String tablePrefix,String platform, String[] srcs, String[] ids, String bt, String et, String sortStr) throws SQLException {
        StringBuilder sb = new StringBuilder();
        boolean hasSource = srcs != null && srcs.length > 0;
        boolean hasid = ids != null && ids.length > 0;
        sb.append("SELECT ID,DAY,SOURCE,PV FROM ").append(tablePrefix).append("_DAY WHERE PLATFORM = ? AND DAY>=? AND DAY<=?");
        if (hasSource) {
            sb.append(" AND SOURCE IN(");
            for (int i = 0; i < srcs.length; ++i) {
                sb.append("?,");
            }
            sb.setCharAt(sb.length() - 1, ')');
        }
        if (hasid) {
            sb.append(" AND ID IN(");
            for (int i = 0; i < ids.length; ++i) {
                sb.append("?,");
            }
            sb.setCharAt(sb.length() - 1, ')');
        }
        if (sortStr != null && sortStr.trim().length() > 0) {
            sb.append(" ORDER BY ").append(sortStr);
        }
        int idx = 1;
        java.sql.PreparedStatement ps = con.prepareStatement(sb.toString());
        try {
            ps.setString(idx++,platform);
            ps.setString(idx++, bt);
            ps.setString(idx++, et);
            if (hasSource) {
                for (int i = 0; i < srcs.length; ++i) {
                    ps.setString(idx++, srcs[i]);
                }
            }
            if (hasid) {
                for (int i = 0; i < ids.length; ++i) {
                    ps.setString(idx++, ids[i]);
                }
            }
            List<DayData> ret = new LinkedList<DayData>();
            java.sql.ResultSet rs = ps.executeQuery();
            try {
                while (rs.next()) {
                    DayData dd = new DayData();
                    dd.setId(rs.getString(1));
                    dd.setDay(rs.getString(2));
                    dd.setSource(rs.getString(3));
                    dd.setPv(rs.getInt(4));
                    ret.add(dd);
                }
                return ret;
            } finally {
                try {
                    rs.close();
                } catch (Exception _m_2) {
                }
            }
        } finally {
            try {
                ps.close();
            } catch (Exception _m_3) {
            }
        }
    }

    public List<DayData> query(Connection con, String tablePrefix,String platform, String id, String bt, String et) throws SQLException {
        StringBuilder sb = new StringBuilder();
        sb.append("SELECT ID,DAY,SOURCE,PV FROM ").append(tablePrefix).append("_DAY WHERE PLATFORM = ? AND DAY>=? AND DAY<=? AND ID=? ORDER BY DAY");
        java.sql.PreparedStatement ps = con.prepareStatement(sb.toString());
        try {
            ps.setString(1,platform);
            ps.setString(2, bt);
            ps.setString(3, et);
            ps.setString(4, id);
            List<DayData> ret = new LinkedList<DayData>();
            java.sql.ResultSet rs = ps.executeQuery();
            try {
                while (rs.next()) {
                    DayData dd = new DayData();
                    dd.setId(rs.getString(1));
                    dd.setDay(rs.getString(2));
                    dd.setSource(rs.getString(3));
                    dd.setPv(rs.getInt(4));
                    ret.add(dd);
                }
                return ret;
            } finally {
                try {
                    rs.close();
                } catch (Exception _m_2) {
                }
            }
        } finally {
            try {
                ps.close();
            } catch (Exception _m_3) {
            }
        }
    }

    public List<DayData> query(Connection con, String tablePrefix,String platform, String bt, String et, @Nullable String[] srcs, int rows) throws SQLException {
        boolean hasSource = srcs != null && srcs.length > 0;
        StringBuilder sb = new StringBuilder();
        sb.append("SELECT ID,SUM(PV) PV FROM ").append(tablePrefix).append("_DAY WHERE PLATFORM = ? AND DAY>=? AND DAY<=?");
        if (hasSource) {
            sb.append(" AND SOURCE IN (");
            for (int i = 0; i < srcs.length; ++i) {
                sb.append("?,");
            }
            sb.setCharAt(sb.length() - 1, ')');
        }
        sb.append(" GROUP BY ID ORDER BY PV DESC LIMIT ?");
        java.sql.PreparedStatement ps = con.prepareStatement(sb.toString());
        try {
            int idx = 1;
            ps.setString(idx++,platform);
            ps.setString(idx++, bt);
            ps.setString(idx++, et);
            if (hasSource) {
                for (String src : srcs)
                    ps.setString(idx++, src);
            }
            ps.setInt(idx++, rows);
            List<DayData> ret = new LinkedList<DayData>();
            java.sql.ResultSet rs = ps.executeQuery();
            try {
                while (rs.next()) {
                    DayData dd = new DayData();
                    dd.setId(rs.getString(1));
                    dd.setPv(rs.getInt(2));
                    ret.add(dd);
                }
                return ret;
            } finally {
                try {
                    rs.close();
                } catch (Exception _m_2) {
                }
            }
        } finally {
            try {
                ps.close();
            } catch (Exception _m_3) {
            }
        }
    }


    @PageQuery
    @OrderBy("ORDER BY c.MODIFY_TIME DESC NULLS LAST")
    @Exclude("descp")
    public abstract PageQueryResult<WareSum> queryWareTime1(Connection con, @Nullable @Like String name, @Nullable @GroupSqlColumn(handlerClass = StringHandler.class, value = {
            "CATEGORY='1' AND OWNER IN(SELECT ID FROM PROFESSOR WHERE NAME LIKE ?)",
            "CATEGORY ='2' AND OWNER IN(SELECT ID FROM ORGANIZATION WHERE NAME LIKE ? OR FOR_SHORT LIKE ?)"},
            additional = 1, isAnd = false, force = true) String author, @Nullable @GtEq @Alias("modifyTime") String bt, @Nullable @Alias("modifyTime") @LtEq String et, int pageSize, int pageNo) throws SQLException;

    public PageQueryResult<WareSum> queryWareTime(Connection con,String platform,String name,String author,String bt,String et,int pageSize,int pageNo) throws SQLException{
        int _m_1 = 0;
        PageQueryResult<WareSum> _result = new PageQueryResult<WareSum>();
        int _m_3 = 1;
        boolean _m_2 = null == name;
        boolean _m_4 = null == author;
        boolean _m_5 = null == bt;
        boolean _m_6 = null == et;
        StringBuilder sql = new StringBuilder();
        boolean _m_8 = true;
        if(!_m_2){
            _m_8 =  false;
            sql.append(" WHERE c.NAME LIKE ?");
        }
        if(!_m_4){
            if(_m_8){
                _m_8 =  false;
                sql.append(" WHERE ((CATEGORY='1' AND OWNER IN(SELECT ID FROM PROFESSOR WHERE NAME LIKE ?)) OR (CATEGORY ='2' AND OWNER IN(SELECT ID FROM ORGANIZATION WHERE NAME LIKE ? OR FOR_SHORT LIKE ?)))");
            }else{
                sql.append(" AND ((CATEGORY='1' AND OWNER IN(SELECT ID FROM PROFESSOR WHERE NAME LIKE ?)) OR (CATEGORY ='2' AND OWNER IN(SELECT ID FROM ORGANIZATION WHERE NAME LIKE ? OR FOR_SHORT LIKE ?)))");
            }
        }
        if(!_m_5){
            if(_m_8){
                _m_8 =  false;
                sql.append(" WHERE c.MODIFY_TIME >= ?");
            }else{
                sql.append(" AND c.MODIFY_TIME >= ?");
            }
        }
        if(!_m_6){
            if(_m_8){
                _m_8 =  false;
                sql.append(" WHERE c.MODIFY_TIME <= ?");
            }else{
                sql.append(" AND c.MODIFY_TIME <= ?");
            }
        }
        StringBuilder _m_7 = sql;
        sql = new StringBuilder();
        sql.append("SELECT COUNT(1) FROM ware c LEFT JOIN ware_day_sum cds on c.id = cds.id AND cds.platform = ?");
        if(_m_7.length()>0){
            sql.append(_m_7);
        }
        PreparedStatement ps = con.prepareStatement(sql.toString());
        try{
            ps.setString(_m_3++,platform);
            if(!_m_2){
                ps.setString(_m_3++,name);
            }
            if(!_m_4){
                ps.setString(_m_3++,author);
                ps.setString(_m_3++,author);
                ps.setString(_m_3++,author);
            }
            if(!_m_5){
                ps.setString(_m_3++,bt);
            }
            if(!_m_6){
                ps.setString(_m_3++,et);
            }
            _result.setPageSize(pageSize);
            ResultSet _pageRs = ps.executeQuery();
            try{
                _pageRs.next();
                _m_1 = _pageRs.getInt(1);
            }finally{
                try{_pageRs.close();}catch(Exception _m_9){}
            }
        }finally{
            try{ps.close();}catch(Exception _m_10){}
        }
        _result.setTotal(_m_1);
        if(0== _m_1){
            _result.setPageNo(1);
            _result.setData(Collections.<WareSum>emptyList());
            return _result;
        }
        _m_3 = 1;
        boolean _m_11 = (1 == pageNo);
        if(_m_11){
            _result.setPageNo(1);
            sql = new StringBuilder();
            sql.append("SELECT cds.platform,COALESCE(cds.sum,0) as sum,c.PAGE_VIEWS,c.ID,c.NAME,c.KEYWORDS,c.CNT,c.COOPERATION,c.CATEGORY,c.OWNER,c.IMAGES,c.STATE,c.SHARE_ID,c.SORT_FIRST,c.CREATE_TIME,c.MODIFY_TIME FROM ware c LEFT JOIN ware_day_sum cds on c.id = cds.id AND cds.platform = ?");
            if(_m_7.length()>0){
                sql.append(_m_7);
            }
            sql.append(" ORDER BY c.MODIFY_TIME DESC NULLS LAST");
            sql.append(" LIMIT ").append(pageSize);
        }else{
            int _m_12 = _m_1 / pageSize;
            if(_m_1 % pageSize != 0){
                ++_m_12;
            }
            if(pageNo > _m_12){
                pageNo = _m_12;
            }
            _result.setPageNo(pageNo);
            --pageNo;
            int _m_13 = (pageNo * pageSize);
            sql = new StringBuilder();
            sql.append("SELECT cds.platform,COALESCE(cds.sum,0) as sum,c.PAGE_VIEWS,c.ID,c.NAME,c.KEYWORDS,c.CNT,c.COOPERATION,c.CATEGORY,c.OWNER,c.IMAGES,c.STATE,c.SHARE_ID,c.SORT_FIRST,c.CREATE_TIME,c.MODIFY_TIME FROM ware c LEFT JOIN ware_day_sum cds on c.id = cds.id AND cds.platform = ?");
            if(_m_7.length()>0){
                sql.append(_m_7);
            }
            sql.append(" ORDER BY c.MODIFY_TIME DESC NULLS LAST");
            sql.append(" LIMIT ").append(pageSize).append(" OFFSET ").append(_m_13);
        }
        ps = con.prepareStatement(sql.toString());
        try{
            ps.setString(_m_3++,platform);
            if(!_m_2){
                ps.setString(_m_3++,name);
            }
            if(!_m_4){
                ps.setString(_m_3++,author);
                ps.setString(_m_3++,author);
                ps.setString(_m_3++,author);
            }
            if(!_m_5){
                ps.setString(_m_3++,bt);
            }
            if(!_m_6){
                ps.setString(_m_3++,et);
            }
            ResultSet rs = ps.executeQuery();
            try{
                List<WareSum> _m_14 = new ArrayList<WareSum>();
                _result.setData(_m_14);
                int _m_15 = 0;
                while((_m_15<pageSize) && rs.next()){
                    ++_m_15;
                    WareSum _obj =  new WareSum();
                    _obj.setPlatform(rs.getString(1));
                    _obj.setSum(rs.getInt(2));
                    _obj.setPageViews(rs.getLong(3));
                    _obj.setId(rs.getString(4));
                    _obj.setName(rs.getString(5));
                    String _m_16 = rs.getString(6);
                    if(rs.wasNull()){
                        _m_16 = null;
                    }
                    _obj.setKeywords(_m_16);
                    String _m_17 = rs.getString(7);
                    if(rs.wasNull()){
                        _m_17 = null;
                    }
                    _obj.setCnt(_m_17);
                    String _m_18 = rs.getString(8);
                    if(rs.wasNull()){
                        _m_18 = null;
                    }
                    _obj.setCooperation(_m_18);
                    _obj.setCategory(rs.getString(9));
                    _obj.setOwner(rs.getString(10));
                    String _m_19 = rs.getString(11);
                    if(rs.wasNull()){
                        _m_19 = null;
                    }
                    _obj.setImages(_m_19);
                    _obj.setState(rs.getString(12));
                    _obj.setShareId(rs.getLong(13));
                    _obj.setSortFirst(rs.getLong(14));
                    _obj.setCreateTime(rs.getString(15));
                    _obj.setModifyTime(rs.getString(16));
                    _m_14.add(_obj);
                }
                return _result;
            }finally{
                try{rs.close();}catch(Exception _m_20){}
            }
        }finally{
            try{ps.close();}catch(Exception _m_21){}
        }
    }

    @PageQuery
    @OrderBy("ORDER BY SUM DESC")
    @Exclude("descp")
    public abstract PageQueryResult<WareSum> queryWareViews1(Connection con, @Nullable @Like String name, @Nullable @GroupSqlColumn(handlerClass = StringHandler.class, value = {
            "CATEGORY='1' AND OWNER IN(SELECT ID FROM PROFESSOR WHERE NAME LIKE ?)",
            "CATEGORY ='2' AND OWNER IN(SELECT ID FROM ORGANIZATION WHERE NAME LIKE ? OR FOR_SHORT LIKE ?)"},
            additional = 1, isAnd = false, force = true) String author, @Nullable @GtEq @Alias("modifyTime") String bt, @Nullable @Alias("modifyTime") @LtEq String et, int pageSize, int pageNo) throws SQLException;

    public PageQueryResult<WareSum> queryWareViews(Connection con,String platform,String name,String author,String bt,String et,int pageSize,int pageNo) throws SQLException{
        int _m_1 = 0;
        PageQueryResult<WareSum> _result = new PageQueryResult<WareSum>();
        int _m_3 = 1;
        boolean _m_2 = null == name;
        boolean _m_4 = null == author;
        boolean _m_5 = null == bt;
        boolean _m_6 = null == et;
        StringBuilder sql = new StringBuilder();
        boolean _m_8 = true;
        if(!_m_2){
            _m_8 =  false;
            sql.append(" WHERE c.NAME LIKE ?");
        }
        if(!_m_4){
            if(_m_8){
                _m_8 =  false;
                sql.append(" WHERE ((CATEGORY='1' AND OWNER IN(SELECT ID FROM PROFESSOR WHERE NAME LIKE ?)) OR (CATEGORY ='2' AND OWNER IN(SELECT ID FROM ORGANIZATION WHERE NAME LIKE ? OR FOR_SHORT LIKE ?)))");
            }else{
                sql.append(" AND ((CATEGORY='1' AND OWNER IN(SELECT ID FROM PROFESSOR WHERE NAME LIKE ?)) OR (CATEGORY ='2' AND OWNER IN(SELECT ID FROM ORGANIZATION WHERE NAME LIKE ? OR FOR_SHORT LIKE ?)))");
            }
        }
        if(!_m_5){
            if(_m_8){
                _m_8 =  false;
                sql.append(" WHERE c.MODIFY_TIME >= ?");
            }else{
                sql.append(" AND c.MODIFY_TIME >= ?");
            }
        }
        if(!_m_6){
            if(_m_8){
                _m_8 =  false;
                sql.append(" WHERE c.MODIFY_TIME <= ?");
            }else{
                sql.append(" AND c.MODIFY_TIME <= ?");
            }
        }
        StringBuilder _m_7 = sql;
        sql = new StringBuilder();
        sql.append("SELECT COUNT(1) FROM ware c LEFT JOIN ware_day_sum cds on c.id = cds.id AND cds.platform = ?");
        if(_m_7.length()>0){
            sql.append(_m_7);
        }
        PreparedStatement ps = con.prepareStatement(sql.toString());
        try{
            ps.setString(_m_3++,platform);
            if(!_m_2){
                ps.setString(_m_3++,name);
            }
            if(!_m_4){
                ps.setString(_m_3++,author);
                ps.setString(_m_3++,author);
                ps.setString(_m_3++,author);
            }
            if(!_m_5){
                ps.setString(_m_3++,bt);
            }
            if(!_m_6){
                ps.setString(_m_3++,et);
            }
            _result.setPageSize(pageSize);
            ResultSet _pageRs = ps.executeQuery();
            try{
                _pageRs.next();
                _m_1 = _pageRs.getInt(1);
            }finally{
                try{_pageRs.close();}catch(Exception _m_9){}
            }
        }finally{
            try{ps.close();}catch(Exception _m_10){}
        }
        _result.setTotal(_m_1);
        if(0== _m_1){
            _result.setPageNo(1);
            _result.setData(Collections.<WareSum>emptyList());
            return _result;
        }
        _m_3 = 1;
        boolean _m_11 = (1 == pageNo);
        if(_m_11){
            _result.setPageNo(1);
            sql = new StringBuilder();
            sql.append("SELECT cds.platform,COALESCE(cds.sum,0) as sum,c.PAGE_VIEWS,c.ID,c.NAME,c.KEYWORDS,c.CNT,c.COOPERATION,c.CATEGORY,c.OWNER,c.IMAGES,c.STATE,c.SHARE_ID,c.SORT_FIRST,c.CREATE_TIME,c.MODIFY_TIME FROM ware c LEFT JOIN ware_day_sum cds on c.id = cds.id AND cds.platform = ?");
            if(_m_7.length()>0){
                sql.append(_m_7);
            }
            sql.append(" ORDER BY SUM DESC");
            sql.append(" LIMIT ").append(pageSize);
        }else{
            int _m_12 = _m_1 / pageSize;
            if(_m_1 % pageSize != 0){
                ++_m_12;
            }
            if(pageNo > _m_12){
                pageNo = _m_12;
            }
            _result.setPageNo(pageNo);
            --pageNo;
            int _m_13 = (pageNo * pageSize);
            sql = new StringBuilder();
            sql.append("SELECT cds.platform,COALESCE(cds.sum,0) as sum,c.PAGE_VIEWS,c.ID,c.NAME,c.KEYWORDS,c.CNT,c.COOPERATION,c.CATEGORY,c.OWNER,c.IMAGES,c.STATE,c.SHARE_ID,c.SORT_FIRST,c.CREATE_TIME,c.MODIFY_TIME FROM ware c LEFT JOIN ware_day_sum cds on c.id = cds.id AND cds.platform = ?");
            if(_m_7.length()>0){
                sql.append(_m_7);
            }
            sql.append(" ORDER BY SUM DESC");
            sql.append(" LIMIT ").append(pageSize).append(" OFFSET ").append(_m_13);
        }
        ps = con.prepareStatement(sql.toString());
        try{
            ps.setString(_m_3++,platform);
            if(!_m_2){
                ps.setString(_m_3++,name);
            }
            if(!_m_4){
                ps.setString(_m_3++,author);
                ps.setString(_m_3++,author);
                ps.setString(_m_3++,author);
            }
            if(!_m_5){
                ps.setString(_m_3++,bt);
            }
            if(!_m_6){
                ps.setString(_m_3++,et);
            }
            ResultSet rs = ps.executeQuery();
            try{
                List<WareSum> _m_14 = new ArrayList<WareSum>();
                _result.setData(_m_14);
                int _m_15 = 0;
                while((_m_15<pageSize) && rs.next()){
                    ++_m_15;
                    WareSum _obj =  new WareSum();
                    _obj.setPlatform(rs.getString(1));
                    _obj.setSum(rs.getInt(2));
                    _obj.setPageViews(rs.getLong(3));
                    _obj.setId(rs.getString(4));
                    _obj.setName(rs.getString(5));
                    String _m_16 = rs.getString(6);
                    if(rs.wasNull()){
                        _m_16 = null;
                    }
                    _obj.setKeywords(_m_16);
                    String _m_17 = rs.getString(7);
                    if(rs.wasNull()){
                        _m_17 = null;
                    }
                    _obj.setCnt(_m_17);
                    String _m_18 = rs.getString(8);
                    if(rs.wasNull()){
                        _m_18 = null;
                    }
                    _obj.setCooperation(_m_18);
                    _obj.setCategory(rs.getString(9));
                    _obj.setOwner(rs.getString(10));
                    String _m_19 = rs.getString(11);
                    if(rs.wasNull()){
                        _m_19 = null;
                    }
                    _obj.setImages(_m_19);
                    _obj.setState(rs.getString(12));
                    _obj.setShareId(rs.getLong(13));
                    _obj.setSortFirst(rs.getLong(14));
                    _obj.setCreateTime(rs.getString(15));
                    _obj.setModifyTime(rs.getString(16));
                    _m_14.add(_obj);
                }
                return _result;
            }finally{
                try{rs.close();}catch(Exception _m_20){}
            }
        }finally{
            try{ps.close();}catch(Exception _m_21){}
        }
    }

    @Exclude("summary")
    @PageQuery
    @OrderBy("ORDER BY c.CREATE_TIME DESC NULLS LAST")
    public abstract PageQueryResult<PpatentSum> queryPpatentTime1(Connection con, @Nullable @Like String name,@Nullable @Like String authors,@Nullable @GtEq @Alias("createTime") String bt, @Nullable @Alias("createTime") @LtEq String et, int pageSize, int pageNo) throws SQLException;

    public PageQueryResult<PpatentSum> queryPpatentTime(Connection con,String platform,String name,String authors,String bt,String et,int pageSize,int pageNo) throws SQLException{
        int _m_1 = 0;
        PageQueryResult<PpatentSum> _result = new PageQueryResult<PpatentSum>();
        int _m_3 = 1;
        boolean _m_2 = null == name;
        boolean _m_4 = null == authors;
        boolean _m_5 = null == bt;
        boolean _m_6 = null == et;
        StringBuilder sql = new StringBuilder();
        boolean _m_8 = true;
        if(!_m_2){
            _m_8 =  false;
            sql.append(" WHERE c.NAME LIKE ?");
        }
        if(!_m_4){
            if(_m_8){
                _m_8 =  false;
                sql.append(" WHERE c.AUTHORS LIKE ?");
            }else{
                sql.append(" AND c.AUTHORS LIKE ?");
            }
        }
        if(!_m_5){
            if(_m_8){
                _m_8 =  false;
                sql.append(" WHERE c.CREATE_TIME >= ?");
            }else{
                sql.append(" AND c.CREATE_TIME >= ?");
            }
        }
        if(!_m_6){
            if(_m_8){
                _m_8 =  false;
                sql.append(" WHERE c.CREATE_TIME <= ?");
            }else{
                sql.append(" AND c.CREATE_TIME <= ?");
            }
        }
        StringBuilder _m_7 = sql;
        sql = new StringBuilder();
        sql.append("SELECT COUNT(1) FROM ppatent c LEFT JOIN ppatent_day_sum cds on c.id = cds.id AND cds.platform = ?");
        if(_m_7.length()>0){
            sql.append(_m_7);
        }
        PreparedStatement ps = con.prepareStatement(sql.toString());
        try{
            ps.setString(_m_3++,platform);
            if(!_m_2){
                ps.setString(_m_3++,name);
            }
            if(!_m_4){
                ps.setString(_m_3++,authors);
            }
            if(!_m_5){
                ps.setString(_m_3++,bt);
            }
            if(!_m_6){
                ps.setString(_m_3++,et);
            }
            _result.setPageSize(pageSize);
            ResultSet _pageRs = ps.executeQuery();
            try{
                _pageRs.next();
                _m_1 = _pageRs.getInt(1);
            }finally{
                try{_pageRs.close();}catch(Exception _m_9){}
            }
        }finally{
            try{ps.close();}catch(Exception _m_10){}
        }
        _result.setTotal(_m_1);
        if(0== _m_1){
            _result.setPageNo(1);
            _result.setData(Collections.<PpatentSum>emptyList());
            return _result;
        }
        _m_3 = 1;
        boolean _m_11 = (1 == pageNo);
        if(_m_11){
            _result.setPageNo(1);
            sql = new StringBuilder();
            sql.append("SELECT cds.platform,COALESCE(cds.sum,0) as sum,c.AUTHORS,c.SORT_NUM,c.ID,c.NAME,c.PAGE_VIEWS,c.CODE,c.REQ_CODE,c.REQ_PERSON,c.REQ_DAY,c.PUB_DAY,c.REF_PARAM,c.KEYWORDS,c.SHARE_ID,c.COOPERATION,c.CREATE_TIME FROM ppatent c LEFT JOIN ppatent_day_sum cds on c.id = cds.id AND cds.platform = ?");
            if(_m_7.length()>0){
                sql.append(_m_7);
            }
            sql.append(" ORDER BY c.CREATE_TIME DESC NULLS LAST");
            sql.append(" LIMIT ").append(pageSize);
        }else{
            int _m_12 = _m_1 / pageSize;
            if(_m_1 % pageSize != 0){
                ++_m_12;
            }
            if(pageNo > _m_12){
                pageNo = _m_12;
            }
            _result.setPageNo(pageNo);
            --pageNo;
            int _m_13 = (pageNo * pageSize);
            sql = new StringBuilder();
            sql.append("SELECT cds.platform,COALESCE(cds.sum,0) as sum,c.AUTHORS,c.SORT_NUM,c.ID,c.NAME,c.PAGE_VIEWS,c.CODE,c.REQ_CODE,c.REQ_PERSON,c.REQ_DAY,c.PUB_DAY,c.REF_PARAM,c.KEYWORDS,c.SHARE_ID,c.COOPERATION,c.CREATE_TIME FROM ppatent c LEFT JOIN ppatent_day_sum cds on c.id = cds.id AND cds.platform = ?");
            if(_m_7.length()>0){
                sql.append(_m_7);
            }
            sql.append(" ORDER BY c.CREATE_TIME DESC NULLS LAST");
            sql.append(" LIMIT ").append(pageSize).append(" OFFSET ").append(_m_13);
        }
        ps = con.prepareStatement(sql.toString());
        try{
            ps.setString(_m_3++,platform);
            if(!_m_2){
                ps.setString(_m_3++,name);
            }
            if(!_m_4){
                ps.setString(_m_3++,authors);
            }
            if(!_m_5){
                ps.setString(_m_3++,bt);
            }
            if(!_m_6){
                ps.setString(_m_3++,et);
            }
            ResultSet rs = ps.executeQuery();
            try{
                List<PpatentSum> _m_14 = new ArrayList<PpatentSum>();
                _result.setData(_m_14);
                int _m_15 = 0;
                while((_m_15<pageSize) && rs.next()){
                    ++_m_15;
                    PpatentSum _obj =  new PpatentSum();
                    _obj.setPlatform(rs.getString(1));
                    _obj.setSum(rs.getInt(2));
                    _obj.setAuthors(rs.getString(3));
                    _obj.setSortNum(rs.getLong(4));
                    _obj.setId(rs.getString(5));
                    _obj.setName(rs.getString(6));
                    _obj.setPageViews(rs.getLong(7));
                    String _m_16 = rs.getString(8);
                    if(rs.wasNull()){
                        _m_16 = null;
                    }
                    _obj.setCode(_m_16);
                    String _m_17 = rs.getString(9);
                    if(rs.wasNull()){
                        _m_17 = null;
                    }
                    _obj.setReqCode(_m_17);
                    String _m_18 = rs.getString(10);
                    if(rs.wasNull()){
                        _m_18 = null;
                    }
                    _obj.setReqPerson(_m_18);
                    String _m_19 = rs.getString(11);
                    if(rs.wasNull()){
                        _m_19 = null;
                    }
                    _obj.setReqDay(_m_19);
                    String _m_20 = rs.getString(12);
                    if(rs.wasNull()){
                        _m_20 = null;
                    }
                    _obj.setPubDay(_m_20);
                    String _m_21 = rs.getString(13);
                    if(rs.wasNull()){
                        _m_21 = null;
                    }
                    _obj.setRef_param(_m_21);
                    String _m_22 = rs.getString(14);
                    if(rs.wasNull()){
                        _m_22 = null;
                    }
                    _obj.setKeywords(_m_22);
                    _obj.setShareId(rs.getLong(15));
                    String _m_23 = rs.getString(16);
                    if(rs.wasNull()){
                        _m_23 = null;
                    }
                    _obj.setCooperation(_m_23);
                    _obj.setCreateTime(rs.getString(17));
                    _m_14.add(_obj);
                }
                return _result;
            }finally{
                try{rs.close();}catch(Exception _m_24){}
            }
        }finally{
            try{ps.close();}catch(Exception _m_25){}
        }
    }

    @Exclude("summary")
    @PageQuery
    @OrderBy("ORDER BY SUM DESC NULLS LAST")
    public abstract PageQueryResult<PpatentSum> queryPpatentViews1(Connection con, @Nullable @Like String name,@Nullable @Like String authors,@Nullable @GtEq @Alias("createTime") String bt, @Nullable @Alias("createTime") @LtEq String et, int pageSize, int pageNo) throws SQLException;

    public PageQueryResult<PpatentSum> queryPpatentViews(Connection con,String platform, String name,String authors,String bt,String et,int pageSize,int pageNo) throws SQLException{
        int _m_1 = 0;
        PageQueryResult<PpatentSum> _result = new PageQueryResult<PpatentSum>();
        int _m_3 = 1;
        boolean _m_2 = null == name;
        boolean _m_4 = null == authors;
        boolean _m_5 = null == bt;
        boolean _m_6 = null == et;
        StringBuilder sql = new StringBuilder();
        boolean _m_8 = true;
        if(!_m_2){
            _m_8 =  false;
            sql.append(" WHERE c.NAME LIKE ?");
        }
        if(!_m_4){
            if(_m_8){
                _m_8 =  false;
                sql.append(" WHERE c.AUTHORS LIKE ?");
            }else{
                sql.append(" AND c.AUTHORS LIKE ?");
            }
        }
        if(!_m_5){
            if(_m_8){
                _m_8 =  false;
                sql.append(" WHERE c.CREATE_TIME >= ?");
            }else{
                sql.append(" AND c.CREATE_TIME >= ?");
            }
        }
        if(!_m_6){
            if(_m_8){
                _m_8 =  false;
                sql.append(" WHERE c.CREATE_TIME <= ?");
            }else{
                sql.append(" AND c.CREATE_TIME <= ?");
            }
        }
        StringBuilder _m_7 = sql;
        sql = new StringBuilder();
        sql.append("SELECT COUNT(1) FROM ppatent c LEFT JOIN ppatent_day_sum cds on c.id = cds.id AND platform = ?");
        if(_m_7.length()>0){
            sql.append(_m_7);
        }
        PreparedStatement ps = con.prepareStatement(sql.toString());
        try{
            ps.setString(_m_3++,platform);
            if(!_m_2){
                ps.setString(_m_3++,name);
            }
            if(!_m_4){
                ps.setString(_m_3++,authors);
            }
            if(!_m_5){
                ps.setString(_m_3++,bt);
            }
            if(!_m_6){
                ps.setString(_m_3++,et);
            }
            _result.setPageSize(pageSize);
            ResultSet _pageRs = ps.executeQuery();
            try{
                _pageRs.next();
                _m_1 = _pageRs.getInt(1);
            }finally{
                try{_pageRs.close();}catch(Exception _m_9){}
            }
        }finally{
            try{ps.close();}catch(Exception _m_10){}
        }
        _result.setTotal(_m_1);
        if(0== _m_1){
            _result.setPageNo(1);
            _result.setData(Collections.<PpatentSum>emptyList());
            return _result;
        }
        _m_3 = 1;
        boolean _m_11 = (1 == pageNo);
        if(_m_11){
            _result.setPageNo(1);
            sql = new StringBuilder();
            sql.append("SELECT cds.platform,COALESCE(cds.sum,0) as sum,c.AUTHORS,c.SORT_NUM,c.ID,c.NAME,c.PAGE_VIEWS,c.CODE,c.REQ_CODE,c.REQ_PERSON,c.REQ_DAY,c.PUB_DAY,c.REF_PARAM,c.KEYWORDS,c.SHARE_ID,c.COOPERATION,c.CREATE_TIME FROM ppatent c LEFT JOIN ppatent_day_sum cds on c.id = cds.id AND platform = ?");
            if(_m_7.length()>0){
                sql.append(_m_7);
            }
            sql.append(" ORDER BY SUM DESC NULLS LAST");
            sql.append(" LIMIT ").append(pageSize);
        }else{
            int _m_12 = _m_1 / pageSize;
            if(_m_1 % pageSize != 0){
                ++_m_12;
            }
            if(pageNo > _m_12){
                pageNo = _m_12;
            }
            _result.setPageNo(pageNo);
            --pageNo;
            int _m_13 = (pageNo * pageSize);
            sql = new StringBuilder();
            sql.append("SELECT cds.platform,COALESCE(cds.sum,0) as sum,c.AUTHORS,c.SORT_NUM,c.ID,c.NAME,c.PAGE_VIEWS,c.CODE,c.REQ_CODE,c.REQ_PERSON,c.REQ_DAY,c.PUB_DAY,c.REF_PARAM,c.KEYWORDS,c.SHARE_ID,c.COOPERATION,c.CREATE_TIME FROM ppatent c LEFT JOIN ppatent_day_sum cds on c.id = cds.id AND platform = ?");
            if(_m_7.length()>0){
                sql.append(_m_7);
            }
            sql.append(" ORDER BY SUM DESC NULLS LAST");
            sql.append(" LIMIT ").append(pageSize).append(" OFFSET ").append(_m_13);
        }
        ps = con.prepareStatement(sql.toString());
        try{
            ps.setString(_m_3++,platform);
            if(!_m_2){
                ps.setString(_m_3++,name);
            }
            if(!_m_4){
                ps.setString(_m_3++,authors);
            }
            if(!_m_5){
                ps.setString(_m_3++,bt);
            }
            if(!_m_6){
                ps.setString(_m_3++,et);
            }
            ResultSet rs = ps.executeQuery();
            try{
                List<PpatentSum> _m_14 = new ArrayList<PpatentSum>();
                _result.setData(_m_14);
                int _m_15 = 0;
                while((_m_15<pageSize) && rs.next()){
                    ++_m_15;
                    PpatentSum _obj =  new PpatentSum();
                    _obj.setPlatform(rs.getString(1));
                    _obj.setSum(rs.getInt(2));
                    _obj.setAuthors(rs.getString(3));
                    _obj.setSortNum(rs.getLong(4));
                    _obj.setId(rs.getString(5));
                    _obj.setName(rs.getString(6));
                    _obj.setPageViews(rs.getLong(7));
                    String _m_16 = rs.getString(8);
                    if(rs.wasNull()){
                        _m_16 = null;
                    }
                    _obj.setCode(_m_16);
                    String _m_17 = rs.getString(9);
                    if(rs.wasNull()){
                        _m_17 = null;
                    }
                    _obj.setReqCode(_m_17);
                    String _m_18 = rs.getString(10);
                    if(rs.wasNull()){
                        _m_18 = null;
                    }
                    _obj.setReqPerson(_m_18);
                    String _m_19 = rs.getString(11);
                    if(rs.wasNull()){
                        _m_19 = null;
                    }
                    _obj.setReqDay(_m_19);
                    String _m_20 = rs.getString(12);
                    if(rs.wasNull()){
                        _m_20 = null;
                    }
                    _obj.setPubDay(_m_20);
                    String _m_21 = rs.getString(13);
                    if(rs.wasNull()){
                        _m_21 = null;
                    }
                    _obj.setRef_param(_m_21);
                    String _m_22 = rs.getString(14);
                    if(rs.wasNull()){
                        _m_22 = null;
                    }
                    _obj.setKeywords(_m_22);
                    _obj.setShareId(rs.getLong(15));
                    String _m_23 = rs.getString(16);
                    if(rs.wasNull()){
                        _m_23 = null;
                    }
                    _obj.setCooperation(_m_23);
                    _obj.setCreateTime(rs.getString(17));
                    _m_14.add(_obj);
                }
                return _result;
            }finally{
                try{rs.close();}catch(Exception _m_24){}
            }
        }finally{
            try{ps.close();}catch(Exception _m_25){}
        }
    }


    @PageQuery
    @OrderBy(" ORDER BY c.publish_time DESC NULLS LAST")
    @Exclude("descp")
    public abstract PageQueryResult<ResourceSum> queryResourceTime1(Connection con, @Nullable @Like String resourceName,@Nullable @GroupSqlColumn(handlerClass = StringHandler.class, value = {
            "RESOURCE_TYPE='1' AND PROFESSOR_ID IN(SELECT ID FROM PROFESSOR WHERE NAME LIKE ?)",
            "RESOURCE_TYPE ='2' AND ORG_ID IN(SELECT ID FROM ORGANIZATION WHERE NAME LIKE ? OR FOR_SHORT LIKE ?)"},
            additional = 1, isAnd = false, force = true) String author, @Nullable @GtEq @Alias("publishTime") String bt, @Nullable @Alias("publishTime") @LtEq String et, int pageSize, int pageNo) throws SQLException;

    public PageQueryResult<ResourceSum> queryResourceTime(Connection con,String platform, String resourceName,String author,String bt,String et,int pageSize,int pageNo) throws SQLException{
        int _m_1 = 0;
        PageQueryResult<ResourceSum> _result = new PageQueryResult<ResourceSum>();
        int _m_3 = 1;
        boolean _m_2 = null == resourceName;
        boolean _m_4 = null == author;
        boolean _m_5 = null == bt;
        boolean _m_6 = null == et;
        StringBuilder sql = new StringBuilder();
        boolean _m_8 = true;
        if(!_m_2){
            _m_8 =  false;
            sql.append(" WHERE c.RESOURCE_NAME LIKE ?");
        }
        if(!_m_4){
            if(_m_8){
                _m_8 =  false;
                sql.append(" WHERE ((RESOURCE_TYPE='1' AND PROFESSOR_ID IN(SELECT ID FROM PROFESSOR WHERE NAME LIKE ?)) OR (RESOURCE_TYPE ='2' AND ORG_ID IN(SELECT ID FROM ORGANIZATION WHERE NAME LIKE ? OR FOR_SHORT LIKE ?)))");
            }else{
                sql.append(" AND ((RESOURCE_TYPE='1' AND PROFESSOR_ID IN(SELECT ID FROM PROFESSOR WHERE NAME LIKE ?)) OR (RESOURCE_TYPE ='2' AND ORG_ID IN(SELECT ID FROM ORGANIZATION WHERE NAME LIKE ? OR FOR_SHORT LIKE ?)))");
            }
        }
        if(!_m_5){
            if(_m_8){
                _m_8 =  false;
                sql.append(" WHERE c.PUBLISH_TIME >= ?");
            }else{
                sql.append(" AND c.PUBLISH_TIME >= ?");
            }
        }
        if(!_m_6){
            if(_m_8){
                _m_8 =  false;
                sql.append(" WHERE c.PUBLISH_TIME <= ?");
            }else{
                sql.append(" AND c.PUBLISH_TIME <= ?");
            }
        }
        StringBuilder _m_7 = sql;
        sql = new StringBuilder();
        sql.append("SELECT COUNT(1) FROM resource c LEFT JOIN resource_day_sum cds on c.resource_id = cds.id AND platform = ?");
        if(_m_7.length()>0){
            sql.append(_m_7);
        }
        PreparedStatement ps = con.prepareStatement(sql.toString());
        try{
            ps.setString(_m_3++,platform);
            if(!_m_2){
                ps.setString(_m_3++,resourceName);
            }
            if(!_m_4){
                ps.setString(_m_3++,author);
                ps.setString(_m_3++,author);
                ps.setString(_m_3++,author);
            }
            if(!_m_5){
                ps.setString(_m_3++,bt);
            }
            if(!_m_6){
                ps.setString(_m_3++,et);
            }
            _result.setPageSize(pageSize);
            ResultSet _pageRs = ps.executeQuery();
            try{
                _pageRs.next();
                _m_1 = _pageRs.getInt(1);
            }finally{
                try{_pageRs.close();}catch(Exception _m_9){}
            }
        }finally{
            try{ps.close();}catch(Exception _m_10){}
        }
        _result.setTotal(_m_1);
        if(0== _m_1){
            _result.setPageNo(1);
            _result.setData(Collections.<ResourceSum>emptyList());
            return _result;
        }
        _m_3 = 1;
        boolean _m_11 = (1 == pageNo);
        if(_m_11){
            _result.setPageNo(1);
            sql = new StringBuilder();
            sql.append("SELECT cds.platform,COALESCE(cds.sum,0) as sum,c.RESOURCE_ID,c.RESOURCE_NAME,c.SUBJECT,c.INDUSTRY,c.SUPPORTED_SERVICES,c.ORG_NAME,c.SPEC,c.PARAMETER,c.STATUS,c.PROFESSOR_ID,c.ASCRIPTION,c.HOPE_PAY_METHOD,c.COOPERATION_NOTES,c.PUBLISH_TIME,c.PAGE_VIEWS,c.COMP,c.RESOURCE_TYPE,c.ORG_ID,c.SHARE_ID,c.SORT_NUM,c.CREATE_TIME,c.MODIFY_TIME FROM resource c LEFT JOIN resource_day_sum cds on c.resource_id = cds.id AND platform = ?");
            if(_m_7.length()>0){
                sql.append(_m_7);
            }
            sql.append(" ORDER BY c.publish_time DESC NULLS LAST");
            sql.append(" LIMIT ").append(pageSize);
        }else{
            int _m_12 = _m_1 / pageSize;
            if(_m_1 % pageSize != 0){
                ++_m_12;
            }
            if(pageNo > _m_12){
                pageNo = _m_12;
            }
            _result.setPageNo(pageNo);
            --pageNo;
            int _m_13 = (pageNo * pageSize);
            sql = new StringBuilder();
            sql.append("SELECT cds.platform,COALESCE(cds.sum,0) as sum,c.RESOURCE_ID,c.RESOURCE_NAME,c.SUBJECT,c.INDUSTRY,c.SUPPORTED_SERVICES,c.ORG_NAME,c.SPEC,c.PARAMETER,c.STATUS,c.PROFESSOR_ID,c.ASCRIPTION,c.HOPE_PAY_METHOD,c.COOPERATION_NOTES,c.PUBLISH_TIME,c.PAGE_VIEWS,c.COMP,c.RESOURCE_TYPE,c.ORG_ID,c.SHARE_ID,c.SORT_NUM,c.CREATE_TIME,c.MODIFY_TIME FROM resource c LEFT JOIN resource_day_sum cds on c.resource_id = cds.id AND platform = ?");
            if(_m_7.length()>0){
                sql.append(_m_7);
            }
            sql.append(" ORDER BY c.publish_time DESC NULLS LAST");
            sql.append(" LIMIT ").append(pageSize).append(" OFFSET ").append(_m_13);
        }
        ps = con.prepareStatement(sql.toString());
        try{
            ps.setString(_m_3++,platform);
            if(!_m_2){
                ps.setString(_m_3++,resourceName);
            }
            if(!_m_4){
                ps.setString(_m_3++,author);
                ps.setString(_m_3++,author);
                ps.setString(_m_3++,author);
            }
            if(!_m_5){
                ps.setString(_m_3++,bt);
            }
            if(!_m_6){
                ps.setString(_m_3++,et);
            }
            ResultSet rs = ps.executeQuery();
            try{
                List<ResourceSum> _m_14 = new ArrayList<ResourceSum>();
                _result.setData(_m_14);
                int _m_15 = 0;
                while((_m_15<pageSize) && rs.next()){
                    ++_m_15;
                    ResourceSum _obj =  new ResourceSum();
                    _obj.setPlatform(rs.getString(1));
                    _obj.setSum(rs.getInt(2));
                    _obj.setResourceId(rs.getString(3));
                    _obj.setResourceName(rs.getString(4));
                    String _m_16 = rs.getString(5);
                    if(rs.wasNull()){
                        _m_16 = null;
                    }
                    _obj.setSubject(_m_16);
                    String _m_17 = rs.getString(6);
                    if(rs.wasNull()){
                        _m_17 = null;
                    }
                    _obj.setIndustry(_m_17);
                    _obj.setSupportedServices(rs.getString(7));
                    String _m_18 = rs.getString(8);
                    if(rs.wasNull()){
                        _m_18 = null;
                    }
                    _obj.setOrgName(_m_18);
                    String _m_19 = rs.getString(9);
                    if(rs.wasNull()){
                        _m_19 = null;
                    }
                    _obj.setSpec(_m_19);
                    String _m_20 = rs.getString(10);
                    if(rs.wasNull()){
                        _m_20 = null;
                    }
                    _obj.setParameter(_m_20);
                    String _m_21 = rs.getString(11);
                    if(rs.wasNull()){
                        _m_21 = null;
                    }
                    _obj.setStatus(_m_21);
                    String _m_22 = rs.getString(12);
                    if(rs.wasNull()){
                        _m_22 = null;
                    }
                    _obj.setProfessorId(_m_22);
                    String _m_23 = rs.getString(13);
                    if(rs.wasNull()){
                        _m_23 = null;
                    }
                    _obj.setAscription(_m_23);
                    String _m_24 = rs.getString(14);
                    if(rs.wasNull()){
                        _m_24 = null;
                    }
                    _obj.setHopePayMethod(_m_24);
                    String _m_25 = rs.getString(15);
                    if(rs.wasNull()){
                        _m_25 = null;
                    }
                    _obj.setCooperationNotes(_m_25);
                    String _m_26 = rs.getString(16);
                    if(rs.wasNull()){
                        _m_26 = null;
                    }
                    _obj.setPublishTime(_m_26);
                    _obj.setPageViews(rs.getInt(17));
                    String _m_27 = rs.getString(18);
                    if(rs.wasNull()){
                        _m_27 = null;
                    }
                    _obj.setComp(_m_27);
                    String _m_28 = rs.getString(19);
                    if(rs.wasNull()){
                        _m_28 = null;
                    }
                    _obj.setResourceType(_m_28);
                    String _m_29 = rs.getString(20);
                    if(rs.wasNull()){
                        _m_29 = null;
                    }
                    _obj.setOrgId(_m_29);
                    _obj.setShareId(rs.getLong(21));
                    _obj.setSortNum(rs.getLong(22));
                    _obj.setCreateTime(rs.getString(23));
                    _obj.setModifyTime(rs.getString(24));
                    _m_14.add(_obj);
                }
                return _result;
            }finally{
                try{rs.close();}catch(Exception _m_30){}
            }
        }finally{
            try{ps.close();}catch(Exception _m_31){}
        }
    }

    @PageQuery
    @OrderBy(" ORDER BY sum DESC")
    @Exclude("descp")
    public abstract PageQueryResult<ResourceSum> queryResourceViews1(Connection con, @Nullable @Like String resourceName,@Nullable @GroupSqlColumn(handlerClass = StringHandler.class, value = {
            "RESOURCE_TYPE='1' AND PROFESSOR_ID IN(SELECT ID FROM PROFESSOR WHERE NAME LIKE ?)",
            "RESOURCE_TYPE ='2' AND ORG_ID IN(SELECT ID FROM ORGANIZATION WHERE NAME LIKE ? OR FOR_SHORT LIKE ?)"},
            additional = 1, isAnd = false, force = true) String author, @Nullable @GtEq @Alias("publishTime") String bt, @Nullable @Alias("publishTime") @LtEq String et, int pageSize, int pageNo) throws SQLException;

    public PageQueryResult<ResourceSum> queryResourceViews(Connection con,String platform, String resourceName,String author,String bt,String et,int pageSize,int pageNo) throws SQLException{
        int _m_1 = 0;
        PageQueryResult<ResourceSum> _result = new PageQueryResult<ResourceSum>();
        int _m_3 = 1;
        boolean _m_2 = null == resourceName;
        boolean _m_4 = null == author;
        boolean _m_5 = null == bt;
        boolean _m_6 = null == et;
        StringBuilder sql = new StringBuilder();
        boolean _m_8 = true;
        if(!_m_2){
            _m_8 =  false;
            sql.append(" WHERE c.RESOURCE_NAME LIKE ?");
        }
        if(!_m_4){
            if(_m_8){
                _m_8 =  false;
                sql.append(" WHERE ((RESOURCE_TYPE='1' AND PROFESSOR_ID IN(SELECT ID FROM PROFESSOR WHERE NAME LIKE ?)) OR (RESOURCE_TYPE ='2' AND ORG_ID IN(SELECT ID FROM ORGANIZATION WHERE NAME LIKE ? OR FOR_SHORT LIKE ?)))");
            }else{
                sql.append(" AND ((RESOURCE_TYPE='1' AND PROFESSOR_ID IN(SELECT ID FROM PROFESSOR WHERE NAME LIKE ?)) OR (RESOURCE_TYPE ='2' AND ORG_ID IN(SELECT ID FROM ORGANIZATION WHERE NAME LIKE ? OR FOR_SHORT LIKE ?)))");
            }
        }
        if(!_m_5){
            if(_m_8){
                _m_8 =  false;
                sql.append(" WHERE c.PUBLISH_TIME >= ?");
            }else{
                sql.append(" AND c.PUBLISH_TIME >= ?");
            }
        }
        if(!_m_6){
            if(_m_8){
                _m_8 =  false;
                sql.append(" WHERE c.PUBLISH_TIME <= ?");
            }else{
                sql.append(" AND c.PUBLISH_TIME <= ?");
            }
        }
        StringBuilder _m_7 = sql;
        sql = new StringBuilder();
        sql.append("SELECT COUNT(1) FROM resource c LEFT JOIN resource_day_sum cds on c.resource_id = cds.id AND platform = ?");
        if(_m_7.length()>0){
            sql.append(_m_7);
        }
        PreparedStatement ps = con.prepareStatement(sql.toString());
        try{
            ps.setString(_m_3++,platform);
            if(!_m_2){
                ps.setString(_m_3++,resourceName);
            }
            if(!_m_4){
                ps.setString(_m_3++,author);
                ps.setString(_m_3++,author);
                ps.setString(_m_3++,author);
            }
            if(!_m_5){
                ps.setString(_m_3++,bt);
            }
            if(!_m_6){
                ps.setString(_m_3++,et);
            }
            _result.setPageSize(pageSize);
            ResultSet _pageRs = ps.executeQuery();
            try{
                _pageRs.next();
                _m_1 = _pageRs.getInt(1);
            }finally{
                try{_pageRs.close();}catch(Exception _m_9){}
            }
        }finally{
            try{ps.close();}catch(Exception _m_10){}
        }
        _result.setTotal(_m_1);
        if(0== _m_1){
            _result.setPageNo(1);
            _result.setData(Collections.<ResourceSum>emptyList());
            return _result;
        }
        _m_3 = 1;
        boolean _m_11 = (1 == pageNo);
        if(_m_11){
            _result.setPageNo(1);
            sql = new StringBuilder();
            sql.append("SELECT cds.platform,COALESCE(cds.sum,0) as sum,c.RESOURCE_ID,c.RESOURCE_NAME,c.SUBJECT,c.INDUSTRY,c.SUPPORTED_SERVICES,c.ORG_NAME,c.SPEC,c.PARAMETER,c.STATUS,c.PROFESSOR_ID,c.ASCRIPTION,c.HOPE_PAY_METHOD,c.COOPERATION_NOTES,c.PUBLISH_TIME,c.PAGE_VIEWS,c.COMP,c.RESOURCE_TYPE,c.ORG_ID,c.SHARE_ID,c.SORT_NUM,c.CREATE_TIME,c.MODIFY_TIME FROM resource c LEFT JOIN resource_day_sum cds on c.resource_id = cds.id AND platform = ?");
            if(_m_7.length()>0){
                sql.append(_m_7);
            }
            sql.append(" ORDER BY sum DESC");
            sql.append(" LIMIT ").append(pageSize);
        }else{
            int _m_12 = _m_1 / pageSize;
            if(_m_1 % pageSize != 0){
                ++_m_12;
            }
            if(pageNo > _m_12){
                pageNo = _m_12;
            }
            _result.setPageNo(pageNo);
            --pageNo;
            int _m_13 = (pageNo * pageSize);
            sql = new StringBuilder();
            sql.append("SELECT cds.platform,COALESCE(cds.sum,0) as sum,c.RESOURCE_ID,c.RESOURCE_NAME,c.SUBJECT,c.INDUSTRY,c.SUPPORTED_SERVICES,c.ORG_NAME,c.SPEC,c.PARAMETER,c.STATUS,c.PROFESSOR_ID,c.ASCRIPTION,c.HOPE_PAY_METHOD,c.COOPERATION_NOTES,c.PUBLISH_TIME,c.PAGE_VIEWS,c.COMP,c.RESOURCE_TYPE,c.ORG_ID,c.SHARE_ID,c.SORT_NUM,c.CREATE_TIME,c.MODIFY_TIME FROM resource c LEFT JOIN resource_day_sum cds on c.resource_id = cds.id AND platform = ?");
            if(_m_7.length()>0){
                sql.append(_m_7);
            }
            sql.append(" ORDER BY sum DESC");
            sql.append(" LIMIT ").append(pageSize).append(" OFFSET ").append(_m_13);
        }
        ps = con.prepareStatement(sql.toString());
        try{
            ps.setString(_m_3++,platform);
            if(!_m_2){
                ps.setString(_m_3++,resourceName);
            }
            if(!_m_4){
                ps.setString(_m_3++,author);
                ps.setString(_m_3++,author);
                ps.setString(_m_3++,author);
            }
            if(!_m_5){
                ps.setString(_m_3++,bt);
            }
            if(!_m_6){
                ps.setString(_m_3++,et);
            }
            ResultSet rs = ps.executeQuery();
            try{
                List<ResourceSum> _m_14 = new ArrayList<ResourceSum>();
                _result.setData(_m_14);
                int _m_15 = 0;
                while((_m_15<pageSize) && rs.next()){
                    ++_m_15;
                    ResourceSum _obj =  new ResourceSum();
                    _obj.setPlatform(rs.getString(1));
                    _obj.setSum(rs.getInt(2));
                    _obj.setResourceId(rs.getString(3));
                    _obj.setResourceName(rs.getString(4));
                    String _m_16 = rs.getString(5);
                    if(rs.wasNull()){
                        _m_16 = null;
                    }
                    _obj.setSubject(_m_16);
                    String _m_17 = rs.getString(6);
                    if(rs.wasNull()){
                        _m_17 = null;
                    }
                    _obj.setIndustry(_m_17);
                    _obj.setSupportedServices(rs.getString(7));
                    String _m_18 = rs.getString(8);
                    if(rs.wasNull()){
                        _m_18 = null;
                    }
                    _obj.setOrgName(_m_18);
                    String _m_19 = rs.getString(9);
                    if(rs.wasNull()){
                        _m_19 = null;
                    }
                    _obj.setSpec(_m_19);
                    String _m_20 = rs.getString(10);
                    if(rs.wasNull()){
                        _m_20 = null;
                    }
                    _obj.setParameter(_m_20);
                    String _m_21 = rs.getString(11);
                    if(rs.wasNull()){
                        _m_21 = null;
                    }
                    _obj.setStatus(_m_21);
                    String _m_22 = rs.getString(12);
                    if(rs.wasNull()){
                        _m_22 = null;
                    }
                    _obj.setProfessorId(_m_22);
                    String _m_23 = rs.getString(13);
                    if(rs.wasNull()){
                        _m_23 = null;
                    }
                    _obj.setAscription(_m_23);
                    String _m_24 = rs.getString(14);
                    if(rs.wasNull()){
                        _m_24 = null;
                    }
                    _obj.setHopePayMethod(_m_24);
                    String _m_25 = rs.getString(15);
                    if(rs.wasNull()){
                        _m_25 = null;
                    }
                    _obj.setCooperationNotes(_m_25);
                    String _m_26 = rs.getString(16);
                    if(rs.wasNull()){
                        _m_26 = null;
                    }
                    _obj.setPublishTime(_m_26);
                    _obj.setPageViews(rs.getInt(17));
                    String _m_27 = rs.getString(18);
                    if(rs.wasNull()){
                        _m_27 = null;
                    }
                    _obj.setComp(_m_27);
                    String _m_28 = rs.getString(19);
                    if(rs.wasNull()){
                        _m_28 = null;
                    }
                    _obj.setResourceType(_m_28);
                    String _m_29 = rs.getString(20);
                    if(rs.wasNull()){
                        _m_29 = null;
                    }
                    _obj.setOrgId(_m_29);
                    _obj.setShareId(rs.getLong(21));
                    _obj.setSortNum(rs.getLong(22));
                    _obj.setCreateTime(rs.getString(23));
                    _obj.setModifyTime(rs.getString(24));
                    _m_14.add(_obj);
                }
                return _result;
            }finally{
                try{rs.close();}catch(Exception _m_30){}
            }
        }finally{
            try{ps.close();}catch(Exception _m_31){}
        }
    }


}
