package com.ekexiu.portal.views.handler.db;


import com.ekexiu.portal.views.pojo.LogEntry;

import java.sql.PreparedStatement;
import java.sql.SQLException;
import java.util.HashMap;
import java.util.Map;

public class TimeLogHandler extends DbLogHandler {

    private String logType;
    private String logTypeAlias;
    private String tableName;

    private String updateSql;
    private String insertSql;
    private String updateSumSql;
    private String insertSumSql;

    protected Map<String, Integer> cache = new HashMap<String, Integer>();

    public String getTableName() {
        return tableName;

    }

    public void setTableName(String tableName) {
        this.tableName = tableName;
        this.updateSql = "UPDATE " + this.tableName + " SET PV= PV+? WHERE ID=? AND DAY =? AND SOURCE =? AND PLATFORM = ?";
        this.insertSql = "INSERT INTO " + this.tableName + " (PV,ID,DAY,SOURCE,PLATFORM) VALUES (?,?,?,?,?)";
        this.updateSumSql = "UPDATE " + this.tableName + "_SUM SET SUM=SUM+? WHERE ID = ? AND PLATFORM = ?";
        this.insertSumSql = "INSERT INTO " + this.tableName + "_SUM (ID,SUM,PLATFORM) VALUES (?,?,?)";
    }

    public String getLogType() {
        return logType;
    }

    public void setLogType(String logType) {
        this.logType = logType;
    }

    public String getLogTypeAlias() {
        return logTypeAlias;
    }

    public void setLogTypeAlias(String logTypeAlias) {
        this.logTypeAlias = logTypeAlias;
    }

    @Override
    public boolean pre() throws Exception {
        LogEntry le;
        long num = 0;
        while ((le = this.queue.poll()) != null) {
            String day = le.getTimeString();
            String id = le.getString("id");
            String source = le.getString("src");
            String platform = le.getString("platform");
            if (id != null && id.length() > 0 && source != null && source.length() == 1 && platform != null && platform.length() > 0) {
                ++num;
                day = day + source + platform + id;
                Integer pv = cache.get(day);
                if (pv == null) {
                    pv = 1;
                } else {
                    pv = pv + 1;
                }
                cache.put(day, pv);
            }
        }
        return num > 0;
    }

    private boolean update(String id, String day, String source, int pv,String platform) throws SQLException {
        PreparedStatement ps = this.con.prepareStatement(this.updateSql);

        try {
            ps.setInt(1, pv);
            ps.setString(2, id);
            ps.setString(3, day);
            ps.setString(4, source);
            ps.setString(5,platform);
            return ps.executeUpdate() == 1;
        } finally {
            try {
                ps.close();
            } catch (Exception e) {
            }
        }
    }

    private boolean updateSum(String id, int pv,String platform) throws SQLException {
        PreparedStatement ps = this.con.prepareStatement(this.updateSumSql);

        try {
            ps.setInt(1, pv);
            ps.setString(2, id);
            ps.setString(3, platform);
            return ps.executeUpdate() == 1;
        } finally {
            try {
                ps.close();
            } catch (Exception e) {
            }
        }
    }

    public void insert(String id, String day, String source, int pv,String platform) throws SQLException {
        PreparedStatement ps = this.con.prepareStatement(this.insertSql);
        try {
            ps.setInt(1, pv);
            ps.setString(2, id);
            ps.setString(3, day);
            ps.setString(4, source);
            ps.setString(5, platform);
            ps.executeUpdate();
        } finally {
            try {
                ps.close();
            } catch (Exception e) {
            }
        }

    }

    public void insertSum(String id,int pv,String platform) throws SQLException {
        PreparedStatement ps = this.con.prepareStatement(this.insertSumSql);
        try {
            ps.setString(1, id);
            ps.setInt(2, pv);
            ps.setString(3, platform);
            ps.executeUpdate();
        } finally {
            try {
                ps.close();
            } catch (Exception e) {
            }
        }

    }

    @Override
    public void stroe() throws SQLException {
        for (Map.Entry<String, Integer> entry : cache.entrySet()) {
            String day = entry.getKey();
            int pv = entry.getValue().intValue();
            String source = day.substring(8, 9);
            String platform = day.substring(9, 41);
            String id = day.substring(41);
            day = day.substring(0, 8);
            if (!this.updateSum(id, pv,platform)) {
                this.insertSum(id,pv, platform);
            }
            if (!this.update(id, day, source, pv,platform)) {
                this.insert(id, day, source, pv,platform);
            }
        }
    }

    @Override
    public void afterCommit() {
        this.cache.clear();
    }

    @Override
    public boolean match(String[] lt) {
        return lt != null && lt.length == 1 && (this.logType.equals(lt[0]) || this.logTypeAlias.equals(lt[0]));
    }

    @Override
    public String toString() {
        return this.getClass().getName() + "[tableName:" + this.tableName + ",logType:" + this.logType + ",logTypeAlias:" + this.logTypeAlias + "]";
    }


}
